package cn.beekee.zhongtong;

import android.os.Bundle;
import android.os.Vibrator;
import android.util.Log;
import cn.beekee.zhongtong.database.DatabaseAdrressHelper;
import cn.beekee.zhongtong.util.AddressAllSelect;
import cn.beekee.zhongtong.util.AddressManager;
import cn.beekee.zhongtong.util.BaiduNameUtil;
import cn.beekee.zhongtong.util.ShakeListener;
import com.baidu.location.BDGeofence;
import com.baidu.location.BDLocation;
import com.baidu.location.BDLocationListener;
import com.baidu.location.LocationClient;
import com.baidu.location.LocationClientOption;

public class AdrLocActivity extends ActivityBase implements BDLocationListener, AddressAllSelect.IAddressSelectListener, AddressManager.IAddressOpeListener {
    protected AddressManager mAddressManager;
    protected String mCityId = "";
    protected String mDistrictId = "";
    private LocationClient mLocationClient = null;
    protected String mProvinceId = "";
    private AddressAllSelect mSelect;
    private ShakeListener mShakeListener;

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.mAddressManager = new AddressManager(this, this);
        this.mSelect = new AddressAllSelect(this, this);
        initBaidu();
        this.mShakeListener = new ShakeListener(this);
        this.mShakeListener.setOnShakeListener(new ShakeListener.OnShakeListener() {
            /* class cn.beekee.zhongtong.AdrLocActivity.AnonymousClass1 */

            @Override // cn.beekee.zhongtong.util.ShakeListener.OnShakeListener
            public void onShake() {
                AdrLocActivity.this.onVibrator();
                AdrLocActivity.this.startPosition();
            }
        });
    }

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onResume() {
        super.onResume();
        this.mShakeListener.start();
    }

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onPause() {
        super.onPause();
        this.mShakeListener.stop();
    }

    private void initBaidu() {
        this.mLocationClient = new LocationClient(this);
        LocationClientOption option = new LocationClientOption();
        option.setLocationMode(LocationClientOption.LocationMode.Hight_Accuracy);
        option.setCoorType(BDGeofence.COORD_TYPE_BD09LL);
        option.setScanSpan(5000);
        option.setIsNeedAddress(true);
        option.setNeedDeviceDirect(true);
        this.mLocationClient.setLocOption(option);
        this.mLocationClient.registerLocationListener(this);
    }

    /* access modifiers changed from: protected */
    public void startSelect() {
        this.mSelect.startSelect();
    }

    /* access modifiers changed from: protected */
    public void startPosition() {
        this.mLocationClient.start();
        this.mLocationClient.requestLocation();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onVibrator() {
        Vibrator vibrator = (Vibrator) getSystemService("vibrator");
        if (vibrator == null) {
            vibrator = (Vibrator) getApplicationContext().getSystemService("vibrator");
        }
        vibrator.vibrate(100);
    }

    @Override // com.baidu.location.BDLocationListener
    public void onReceiveLocation(BDLocation location) {
        if (location != null) {
            this.mLocationClient.stop();
            String province = BaiduNameUtil.BaiduToZTO(location.getProvince());
            Log.e("", "" + province);
            String city = location.getCity();
            Log.e("", "" + city);
            String district = location.getDistrict();
            Log.e("", "" + district);
            this.mAddressManager.getProvinceCode(province);
            this.mAddressManager.getCityCode(DatabaseAdrressHelper.TYPE_GET_PROVINCE + province, city);
            this.mAddressManager.getDistrictCode(DatabaseAdrressHelper.TYPE_GET_PROVINCE + province + city, district);
        }
    }

    @Override // cn.beekee.zhongtong.util.AddressAllSelect.IAddressSelectListener
    public void pickAddress(String province, String provinceCode, String city, String cityCode, String district, String districtCode) {
        this.mProvinceId = provinceCode;
        this.mCityId = cityCode;
        this.mDistrictId = districtCode;
    }

    @Override // cn.beekee.zhongtong.util.AddressManager.IAddressOpeListener
    public void onAddressOver(int flag, Object result) {
        if (result != null) {
            if (flag == 6) {
                this.mProvinceId = (String) result;
            } else if (flag == 7) {
                this.mCityId = (String) result;
            } else if (flag == 8) {
                this.mDistrictId = (String) result;
            }
        }
    }

    public void onDestroy() {
        super.onDestroy();
        this.mLocationClient.unRegisterLocationListener(this);
        if (this.mSelect != null) {
            this.mSelect.closeSelect();
        }
    }
}
