package cn.beekee.zhongtong;

import android.app.Fragment;
import android.os.Bundle;
import android.os.Handler;
import android.text.TextUtils;
import android.util.Log;
import android.view.KeyEvent;
import android.view.View;
import android.widget.RadioGroup;
import android.widget.Toast;
import cn.beekee.zhongtong.bean.LoginBean;
import cn.beekee.zhongtong.fragment.FragmentLogin;
import cn.beekee.zhongtong.fragment.FragmentMain;
import cn.beekee.zhongtong.fragment.FragmentMsg;
import cn.beekee.zhongtong.fragment.FragmentMy;
import cn.beekee.zhongtong.fragment.FragmentSetting;
import cn.beekee.zhongtong.util.AddressManager;
import cn.beekee.zhongtong.util.DialogHint;
import cn.beekee.zhongtong.util.MySharePreference;
import cn.beekee.zhongtong.util.StaticParam;
import cn.beekee.zhongtong.util.SweetDialogCreator;
import java.io.Serializable;

public class MainActivity extends ActivityBase implements AddressManager.IAddressOpeListener, DialogHint.IDialogListener {
    private static final String SAVE_FRAGMENT_POSITION = "fragment_position";
    private static final String SAVE_LOGIN_BEAN = "login_bean";
    public static int gLogin;
    public static LoginBean gLoginBean;
    boolean mFlag = false;
    private FragmentPosition mFragmentPosition = FragmentPosition.MAIN;
    Fragment[] mFragments = {new FragmentMain(), new FragmentMsg(), new FragmentLogin(), new FragmentSetting()};
    private RadioGroup mGroup;

    /* access modifiers changed from: package-private */
    public enum FragmentPosition {
        MAIN,
        MY,
        MSG,
        SETTING
    }

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        if (savedInstanceState != null) {
            removeLastLayout();
        }
        getFragmentManager().beginTransaction().add(R.id.main_container, this.mFragments[0], "0").add(R.id.main_container, this.mFragments[1], "1").add(R.id.main_container, this.mFragments[2], "2").add(R.id.main_container, this.mFragments[3], "3").commit();
        this.mGroup = (RadioGroup) findViewById(R.id.main_select_rg);
        if (!MySharePreference.getHasAddress(this)) {
            new AddressManager(this, this).updateDataPre();
        }
        showMain(null);
    }

    private void removeLastLayout() {
        Fragment lastFragment0 = getFragmentManager().findFragmentByTag("0");
        if (lastFragment0 != null) {
            Fragment lastFragment1 = getFragmentManager().findFragmentByTag("1");
            Fragment lastFragment2 = getFragmentManager().findFragmentByTag("2");
            getFragmentManager().beginTransaction().remove(lastFragment0).remove(lastFragment1).remove(lastFragment2).remove(getFragmentManager().findFragmentByTag("3")).commit();
        }
    }

    /* access modifiers changed from: protected */
    public void onRestoreInstanceState(Bundle savedInstanceState) {
        super.onRestoreInstanceState(savedInstanceState);
        if (savedInstanceState != null) {
            this.mFragmentPosition = (FragmentPosition) savedInstanceState.getSerializable(SAVE_FRAGMENT_POSITION);
            switch (this.mFragmentPosition) {
                case MAIN:
                    showMain(null);
                    break;
                case MSG:
                    showMsg(null);
                    break;
                case MY:
                    showMy(null);
                    break;
                case SETTING:
                    showSetting(null);
                    break;
            }
            Serializable loginBeanObject = savedInstanceState.getSerializable(SAVE_LOGIN_BEAN);
            if (loginBeanObject != null && (loginBeanObject instanceof LoginBean)) {
                gLoginBean = (LoginBean) loginBeanObject;
            }
            if (gLoginBean != null) {
                loginSuc(gLoginBean);
            }
        }
    }

    /* access modifiers changed from: protected */
    public void onSaveInstanceState(Bundle outState) {
        saveData(outState);
        super.onSaveInstanceState(outState);
        Log.e("", "++++++++++++++onSaveInstanceState");
    }

    private void saveData(Bundle outState) {
        outState.putSerializable(SAVE_FRAGMENT_POSITION, this.mFragmentPosition);
        if (gLoginBean != null) {
            outState.putSerializable(SAVE_LOGIN_BEAN, gLoginBean);
        }
    }

    public void showMain(View view) {
        getFragmentManager().beginTransaction().hide(this.mFragments[1]).hide(this.mFragments[2]).hide(this.mFragments[3]).show(this.mFragments[0]).commit();
        this.mFragmentPosition = FragmentPosition.MAIN;
    }

    public void showMsg(View view) {
        getFragmentManager().beginTransaction().hide(this.mFragments[0]).hide(this.mFragments[2]).hide(this.mFragments[3]).show(this.mFragments[1]).commit();
        this.mFragmentPosition = FragmentPosition.MSG;
    }

    public void showMy(View view) {
        getFragmentManager().beginTransaction().hide(this.mFragments[0]).hide(this.mFragments[1]).hide(this.mFragments[3]).show(this.mFragments[2]).commit();
        this.mFragmentPosition = FragmentPosition.MY;
    }

    public void showSetting(View view) {
        getFragmentManager().beginTransaction().hide(this.mFragments[0]).hide(this.mFragments[1]).hide(this.mFragments[2]).show(this.mFragments[3]).commit();
        this.mFragmentPosition = FragmentPosition.SETTING;
    }

    public boolean checkSend() {
        if (gLoginBean != null && !TextUtils.isEmpty(gLoginBean.getOpenId())) {
            return true;
        }
        DialogHint.showDialog(this, "请先登录账号，才能寄件", this);
        return false;
    }

    @Override // cn.beekee.zhongtong.util.DialogHint.IDialogListener
    public void clickOK(boolean ok) {
        if (ok) {
            this.mGroup.check(R.id.rg_my);
            showMy(null);
        }
    }

    @Override // cn.beekee.zhongtong.util.AddressManager.IAddressOpeListener
    public void onAddressOver(int flag, Object result) {
        if (((Boolean) result).booleanValue()) {
            Toast.makeText(this, "初始化数据成功", 0).show();
            MySharePreference.setHasAddress(this, true);
            return;
        }
        Toast.makeText(this, "初始化数据失败,可重新进入应用,再次初始化", 1).show();
    }

    @Override // cn.beekee.zhongtong.util.net.NetTaskManager.INetListener, cn.beekee.zhongtong.ActivityBase
    public boolean netResult(int flag, Object result) {
        if (!super.netResult(flag, result)) {
            return false;
        }
        if (flag == gLogin) {
            LoginBean userBean = new LoginBean((String) result);
            if (!userBean.isParseResult()) {
                SweetDialogCreator.showError(this, StaticParam.NET_SERVICE_DATA_FAIL);
                return false;
            } else if (!userBean.isResult()) {
                SweetDialogCreator.showError(this, userBean.getMessage());
                return false;
            } else {
                loginSuc(userBean);
            }
        }
        return true;
    }

    public void loginSuc(LoginBean userBean) {
        gLoginBean = userBean;
        changeFragment(new FragmentMy());
    }

    public void loginQuit() {
        gLoginBean = null;
        changeFragment(new FragmentLogin());
    }

    private void changeFragment(Fragment fragment) {
        getFragmentManager().beginTransaction().remove(this.mFragments[2]).add(R.id.main_container, fragment).commit();
        this.mFragments[2] = fragment;
    }

    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if (keyCode == 4) {
            if (!this.mFlag) {
                Toast.makeText(this, "再次点击返回键退出", 0).show();
                new Handler().postDelayed(new Runnable() {
                    /* class cn.beekee.zhongtong.MainActivity.AnonymousClass1 */

                    public void run() {
                        MainActivity.this.mFlag = false;
                    }
                }, 2000);
                this.mFlag = true;
                return true;
            }
            gLoginBean = null;
        }
        return super.onKeyDown(keyCode, event);
    }
}
