package cn.beekee.zhongtong.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.util.Log;
import java.io.IOException;
import java.io.RandomAccessFile;

public class DatabaseAdrressHelper {
    public static final String TABLE_NAME = "address";
    public static final String TYPE_GET_CITY = "中国河南省";
    public static final String TYPE_GET_DISTRICT = "中国河南省周口市";
    public static final String TYPE_GET_PROVINCE = "中国";
    public static final String TYPE_KEY = "type_key";
    public static final String VALUE_KEY = "value_key";
    private static DatabaseAdrressHelper mAddressDatabase;
    public DatabaseCreate mHelp;

    private DatabaseAdrressHelper(Context context) {
        this.mHelp = new DatabaseCreate(context);
    }

    public static DatabaseAdrressHelper getInstance(Context context) {
        if (mAddressDatabase == null) {
            mAddressDatabase = new DatabaseAdrressHelper(context);
        }
        return mAddressDatabase;
    }

    public boolean insertValue(String type, String value) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(type, value);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.insert("address", null, values) != -1) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public String getValue(String type) {
        SQLiteDatabase database;
        String str = null;
        synchronized (DatabaseCreate.LOCK) {
            StringBuilder provinces = new StringBuilder();
            if (this.mHelp != null && (database = this.mHelp.getReadableDatabase()) != null) {
                Cursor cursor = database.query("address", new String[]{VALUE_KEY}, "type_key= ?", new String[]{type}, null, null, null);
                int index = cursor.getColumnIndex(VALUE_KEY);
                while (cursor.moveToNext()) {
                    provinces.append(cursor.getString(index));
                }
                cursor.close();
                database.close();
                str = provinces.toString();
            }
        }
        return str;
    }

    private ContentValues warpValues(String type, String value) {
        if (type == null || value == null) {
            return null;
        }
        ContentValues values = new ContentValues();
        values.put(TYPE_KEY, type);
        values.put(VALUE_KEY, value);
        return values;
    }

    public void clearTable() {
        synchronized (DatabaseCreate.LOCK) {
            SQLiteDatabase database = this.mHelp.getWritableDatabase();
            if (database != null) {
                database.execSQL("delete from address");
                database.close();
            }
        }
    }

    public boolean initInsertAddress(RandomAccessFile accessFile) throws IOException {
        boolean z;
        synchronized (DatabaseCreate.LOCK) {
            SQLiteDatabase database = this.mHelp.getWritableDatabase();
            long startTime = System.currentTimeMillis();
            database.beginTransaction();
            while (true) {
                String key = accessFile.readUTF();
                String value = accessFile.readUTF();
                ContentValues values = warpValues(key, value);
                if (values != null && database.insert("address", null, values) != -1) {
                    System.out.println("====key::" + key + "===value::" + value);
                    if (accessFile.length() == accessFile.getFilePointer()) {
                        database.setTransactionSuccessful();
                        database.endTransaction();
                        database.close();
                        Log.e("", "写数据库花费了：" + ((System.currentTimeMillis() - startTime) / 1000) + "秒");
                        z = true;
                        break;
                    }
                } else {
                    database.endTransaction();
                    z = false;
                }
            }
        }
        return z;
    }

    public void prepareInit() {
        SQLiteDatabase database;
        if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
            database.beginTransaction();
        }
    }

    public boolean startInit(String type, String value) {
        SQLiteDatabase database;
        boolean result;
        ContentValues values = warpValues(type, value);
        if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
            return false;
        }
        if (database.insert("address", null, values) != -1) {
            result = true;
        } else {
            result = false;
        }
        return result;
    }

    public void endInit() {
        SQLiteDatabase database;
        if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
            database.execSQL("CREATE INDEX _ca ON address(type_key)");
            database.setTransactionSuccessful();
            database.endTransaction();
            database.close();
        }
    }
}
