package cn.beekee.zhongtong.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class DatabaseRangeHistoryHelper {
    public static final String ADDRESS_KEY = "address";
    public static final String CODE_KEY = "code";
    public static final String DATE_KEY = "date";
    public static final String TABLE_NAME = "range_search_history";
    private static DatabaseRangeHistoryHelper mRangeHistoryDatabase;
    public DatabaseCreate mHelp;

    private DatabaseRangeHistoryHelper(Context context) {
        this.mHelp = new DatabaseCreate(context);
    }

    public static DatabaseRangeHistoryHelper getInstance(Context context) {
        if (mRangeHistoryDatabase == null) {
            mRangeHistoryDatabase = new DatabaseRangeHistoryHelper(context);
        }
        return mRangeHistoryDatabase;
    }

    public boolean insert(String address, String addressCode, String date) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(address, addressCode, date);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.insert(TABLE_NAME, null, values) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean delete(String addressCode) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            if (this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.delete(TABLE_NAME, "code = ?", new String[]{addressCode}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean update(String address, String addressCode, String date) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(address, addressCode, date);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.update(TABLE_NAME, values, "code = ?", new String[]{addressCode}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public List<Map<String, String>> query(String addressCode) {
        List<Map<String, String>> list;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            list = new ArrayList<>();
            if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
                Cursor cursor = database.query(TABLE_NAME, null, "code=?", new String[]{addressCode}, null, null, null);
                int addressIndex = cursor.getColumnIndex("address");
                int addressCodeIndex = cursor.getColumnIndex(CODE_KEY);
                int dateIndex = cursor.getColumnIndex("date");
                while (cursor.moveToNext()) {
                    Map<String, String> map = new HashMap<>();
                    map.put("address", cursor.getString(addressIndex));
                    map.put(CODE_KEY, cursor.getString(addressCodeIndex));
                    map.put("date", cursor.getString(dateIndex));
                    list.add(map);
                }
                database.close();
            }
        }
        return list;
    }

    public List<Map<String, String>> query() {
        List<Map<String, String>> list;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            list = new ArrayList<>();
            if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
                Cursor cursor = database.query(TABLE_NAME, null, null, null, null, null, "date desc");
                int addressIndex = cursor.getColumnIndex("address");
                int addressCodeIndex = cursor.getColumnIndex(CODE_KEY);
                int dateIndex = cursor.getColumnIndex("date");
                while (cursor.moveToNext()) {
                    Map<String, String> map = new HashMap<>();
                    map.put("address", cursor.getString(addressIndex));
                    map.put(CODE_KEY, cursor.getString(addressCodeIndex));
                    map.put("date", cursor.getString(dateIndex));
                    list.add(map);
                }
                database.close();
            }
        }
        return list;
    }

    public void clearTable() {
        synchronized (DatabaseCreate.LOCK) {
            SQLiteDatabase database = this.mHelp.getWritableDatabase();
            if (database != null) {
                database.execSQL("delete from range_search_history");
                database.close();
            }
        }
    }

    private ContentValues warpValues(String address, String addressCode, String date) {
        if (address == null || addressCode == null || date == null) {
            return null;
        }
        ContentValues values = new ContentValues();
        values.put("address", address);
        values.put(CODE_KEY, addressCode);
        values.put("date", date);
        return values;
    }
}
