package cn.beekee.zhongtong.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.text.TextUtils;
import cn.beekee.zhongtong.bean.RegisterMsgBean;
import java.util.ArrayList;
import java.util.List;

public class DatabaseRegisterHelper {
    public static final String DATE_KEY = "date";
    public static final String SERVER_ID = "server_id";
    public static final String TABLE_NAME = "register_billCode";
    public static final String WAYBILL_CONTENT = "waybill_content";
    public static final String WAYBILL_KEY = "waybill";
    private static DatabaseRegisterHelper mRegisterHelper;
    public DatabaseCreate mHelp;

    private DatabaseRegisterHelper(Context context) {
        this.mHelp = new DatabaseCreate(context);
    }

    public static DatabaseRegisterHelper getInstance(Context context) {
        if (mRegisterHelper == null) {
            mRegisterHelper = new DatabaseRegisterHelper(context);
        }
        return mRegisterHelper;
    }

    public boolean insert(String id, String wayBill, String wayBillContent, String date) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(id, wayBill, wayBillContent, date);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.insert(TABLE_NAME, null, values) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean delete(String wayBill) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            if (this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.delete(TABLE_NAME, "waybill = ?", new String[]{wayBill}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean update(String wayBill, String wayBillContent, String date) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(wayBillContent, date);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.update(TABLE_NAME, values, "waybill = ?", new String[]{wayBill}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public RegisterMsgBean query(String wayBill) {
        RegisterMsgBean msgBean;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            if (this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                msgBean = null;
            } else {
                Cursor cursor = database.query(TABLE_NAME, null, "waybill=?", new String[]{wayBill}, null, null, null);
                int serverIdIndex = cursor.getColumnIndex(SERVER_ID);
                int waybillContentIndex = cursor.getColumnIndex(WAYBILL_CONTENT);
                int dateIndex = cursor.getColumnIndex("date");
                msgBean = null;
                while (cursor.moveToNext()) {
                    msgBean = new RegisterMsgBean(cursor.getString(serverIdIndex), wayBill, cursor.getString(waybillContentIndex), cursor.getString(dateIndex));
                }
                database.close();
            }
        }
        return msgBean;
    }

    public List<RegisterMsgBean> query() {
        List<RegisterMsgBean> list;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            list = new ArrayList<>();
            if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
                Cursor cursor = database.query(TABLE_NAME, null, null, null, null, null, "date desc");
                int serverIdIndex = cursor.getColumnIndex(SERVER_ID);
                int waybillIndex = cursor.getColumnIndex("waybill");
                int waybillContentIndex = cursor.getColumnIndex(WAYBILL_CONTENT);
                int dateIndex = cursor.getColumnIndex("date");
                while (cursor.moveToNext()) {
                    String id = cursor.getString(serverIdIndex);
                    String wayBill = cursor.getString(waybillIndex);
                    String wayBillContent = cursor.getString(waybillContentIndex);
                    String date = cursor.getString(dateIndex);
                    if (!TextUtils.isEmpty(wayBillContent)) {
                        list.add(new RegisterMsgBean(id, wayBill, wayBillContent, date));
                    }
                }
                database.close();
            }
        }
        return list;
    }

    private ContentValues warpValues(String wayBillContent, String date) {
        ContentValues values = new ContentValues();
        values.put(WAYBILL_CONTENT, wayBillContent);
        values.put("date", date);
        return values;
    }

    private ContentValues warpValues(String id, String wayBill, String wayBillContent, String date) {
        ContentValues values = new ContentValues();
        values.put(SERVER_ID, id);
        values.put("waybill", wayBill);
        values.put(WAYBILL_CONTENT, wayBillContent);
        values.put("date", date);
        return values;
    }
}
