package cn.beekee.zhongtong.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import cn.beekee.zhongtong.bean.SiteInfoBean;
import cn.beekee.zhongtong.util.DateUtil;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class DatabaseSiteInfoHelper {
    public static final String DATE_KEY = "date";
    public static final String SITE_ADDRESS = "site_address";
    public static final String SITE_CITY = "site_city";
    public static final String SITE_DISPATCH = "site_dispatch";
    public static final String SITE_DISPATCH_NOT = "site_dispatch_not";
    public static final String SITE_DISTRICT = "site_district";
    public static final String SITE_FAX = "site_fax";
    public static final String SITE_ID = "site_id";
    public static final String SITE_LATITUDE = "site_latitude";
    public static final String SITE_LONGITUDE = "site_longitude";
    public static final String SITE_MANAGER = "site_manager";
    public static final String SITE_NAME = "site_name";
    public static final String SITE_PARENT = "site_parent";
    public static final String SITE_PHONE = "site_phone";
    public static final String SITE_PROVINCE = "site_province";
    public static final String SITE_STATUS = "site_status";
    public static final String TABLE_NAME = "site_info";
    private static DatabaseSiteInfoHelper mSiteInfoDatabase;
    public DatabaseCreate mHelp;

    private DatabaseSiteInfoHelper(Context context) {
        this.mHelp = new DatabaseCreate(context);
    }

    public static DatabaseSiteInfoHelper getInstance(Context context) {
        if (mSiteInfoDatabase == null) {
            mSiteInfoDatabase = new DatabaseSiteInfoHelper(context);
        }
        return mSiteInfoDatabase;
    }

    public boolean insert(SiteInfoBean infoBean) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(infoBean);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.insert(TABLE_NAME, null, values) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean delete(String siteId) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            if (this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.delete(TABLE_NAME, "site_id = ?", new String[]{siteId}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean update(SiteInfoBean infoBean) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(infoBean);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.update(TABLE_NAME, values, "site_id = ?", new String[]{infoBean.getSiteId()}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public SiteInfoBean query(String siteId) {
        SQLiteDatabase database;
        SiteInfoBean infoBean;
        synchronized (DatabaseCreate.LOCK) {
            try {
                if (this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                    return null;
                }
                Cursor cursor = database.query(TABLE_NAME, null, "site_id=?", new String[]{siteId}, null, null, null);
                int siteIdIndex = cursor.getColumnIndex(SITE_ID);
                int siteManagerIndex = cursor.getColumnIndex(SITE_MANAGER);
                int siteNameIndex = cursor.getColumnIndex(SITE_NAME);
                int sitePhoneIndex = cursor.getColumnIndex(SITE_PHONE);
                int siteStatusIndex = cursor.getColumnIndex(SITE_STATUS);
                int siteProIndex = cursor.getColumnIndex(SITE_PROVINCE);
                int siteCityIndex = cursor.getColumnIndex(SITE_CITY);
                int siteDisIndex = cursor.getColumnIndex(SITE_DISTRICT);
                int siteParentIndex = cursor.getColumnIndex(SITE_PARENT);
                int siteFaxIndex = cursor.getColumnIndex(SITE_FAX);
                int siteDispatchIndex = cursor.getColumnIndex(SITE_DISPATCH);
                int siteDispatchNotIndex = cursor.getColumnIndex(SITE_DISPATCH_NOT);
                int siteAddressIndex = cursor.getColumnIndex(SITE_ADDRESS);
                int siteLongitudeIndex = cursor.getColumnIndex(SITE_LONGITUDE);
                int siteLatitudeIndex = cursor.getColumnIndex(SITE_LATITUDE);
                if (cursor.moveToNext()) {
                    infoBean = new SiteInfoBean(cursor.getString(siteIdIndex), cursor.getString(siteManagerIndex), cursor.getString(siteNameIndex), cursor.getString(sitePhoneIndex), cursor.getString(siteStatusIndex), cursor.getString(siteProIndex), cursor.getString(siteCityIndex), cursor.getString(siteDisIndex), cursor.getString(siteParentIndex), cursor.getString(siteFaxIndex), cursor.getString(siteDispatchIndex), cursor.getString(siteDispatchNotIndex), cursor.getString(siteAddressIndex), cursor.getString(siteLongitudeIndex), cursor.getString(siteLatitudeIndex));
                } else {
                    infoBean = null;
                }
                database.close();
                return infoBean;
            } catch (Throwable th) {
                th = th;
                throw th;
            }
        }
    }

    public List<SiteInfoBean> query() {
        List<SiteInfoBean> list;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            list = new ArrayList<>();
            if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
                Cursor cursor = database.query(TABLE_NAME, null, null, null, null, null, "site_province desc");
                int siteIdIndex = cursor.getColumnIndex(SITE_ID);
                int siteManagerIndex = cursor.getColumnIndex(SITE_MANAGER);
                int siteNameIndex = cursor.getColumnIndex(SITE_NAME);
                int sitePhoneIndex = cursor.getColumnIndex(SITE_PHONE);
                int siteStatusIndex = cursor.getColumnIndex(SITE_STATUS);
                int siteProIndex = cursor.getColumnIndex(SITE_PROVINCE);
                int siteCityIndex = cursor.getColumnIndex(SITE_CITY);
                int siteDisIndex = cursor.getColumnIndex(SITE_DISTRICT);
                int siteParentIndex = cursor.getColumnIndex(SITE_PARENT);
                int siteFaxIndex = cursor.getColumnIndex(SITE_FAX);
                int siteDispatchIndex = cursor.getColumnIndex(SITE_DISPATCH);
                int siteDispatchNotIndex = cursor.getColumnIndex(SITE_DISPATCH_NOT);
                int siteAddressIndex = cursor.getColumnIndex(SITE_ADDRESS);
                int siteLongitudeIndex = cursor.getColumnIndex(SITE_LONGITUDE);
                int siteLatitudeIndex = cursor.getColumnIndex(SITE_LATITUDE);
                while (cursor.moveToNext()) {
                    list.add(new SiteInfoBean(cursor.getString(siteIdIndex), cursor.getString(siteManagerIndex), cursor.getString(siteNameIndex), cursor.getString(sitePhoneIndex), cursor.getString(siteStatusIndex), cursor.getString(siteProIndex), cursor.getString(siteCityIndex), cursor.getString(siteDisIndex), cursor.getString(siteParentIndex), cursor.getString(siteFaxIndex), cursor.getString(siteDispatchIndex), cursor.getString(siteDispatchNotIndex), cursor.getString(siteAddressIndex), cursor.getString(siteLongitudeIndex), cursor.getString(siteLatitudeIndex)));
                }
                database.close();
            }
        }
        return list;
    }

    public void clearTable() {
        synchronized (DatabaseCreate.LOCK) {
            SQLiteDatabase database = this.mHelp.getWritableDatabase();
            if (database != null) {
                database.execSQL("delete from site_info");
                database.close();
            }
        }
    }

    private ContentValues warpValues(SiteInfoBean infoBean) {
        if (infoBean == null) {
            return null;
        }
        ContentValues values = new ContentValues();
        values.put(SITE_ID, infoBean.getSiteId());
        values.put(SITE_MANAGER, infoBean.getSiteManager());
        values.put(SITE_NAME, infoBean.getSiteName());
        values.put(SITE_PHONE, infoBean.getSitePhone());
        values.put(SITE_STATUS, infoBean.getSiteEnable());
        values.put(SITE_PROVINCE, infoBean.getSiteProvince());
        values.put(SITE_CITY, infoBean.getSiteCity());
        values.put(SITE_DISTRICT, infoBean.getSiteDistrict());
        values.put(SITE_PARENT, infoBean.getSiteParent());
        values.put(SITE_FAX, infoBean.getSiteFax());
        values.put(SITE_DISPATCH, infoBean.getSiteDispatch());
        values.put(SITE_DISPATCH_NOT, infoBean.getSiteDispatchNot());
        values.put(SITE_ADDRESS, infoBean.getSiteAddress());
        values.put(SITE_LONGITUDE, infoBean.getSiteLongitude());
        values.put(SITE_LATITUDE, infoBean.getSiteLatitude());
        values.put("date", DateUtil.orderFormat(new Date()));
        return values;
    }
}
