package cn.beekee.zhongtong.database;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class DatabaseWayBillHelper {
    public static final String DATE_KEY = "date";
    public static final String TABLE_NAME = "waybill_history";
    public static final String WAYBILL_KEY = "waybill";
    private static DatabaseWayBillHelper mWaybillDatabase;
    public DatabaseCreate mHelp;

    private DatabaseWayBillHelper(Context context) {
        this.mHelp = new DatabaseCreate(context);
    }

    public static DatabaseWayBillHelper getInstance(Context context) {
        if (mWaybillDatabase == null) {
            mWaybillDatabase = new DatabaseWayBillHelper(context);
        }
        return mWaybillDatabase;
    }

    public boolean insert(String wayBill, String date) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(wayBill, date);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.insert(TABLE_NAME, null, values) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean delete(String wayBill) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            if (this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.delete(TABLE_NAME, "waybill = ?", new String[]{wayBill}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public boolean update(String wayBill, String date) {
        SQLiteDatabase database;
        boolean result;
        synchronized (DatabaseCreate.LOCK) {
            ContentValues values = warpValues(wayBill, date);
            if (values == null || this.mHelp == null || (database = this.mHelp.getWritableDatabase()) == null) {
                return false;
            }
            if (database.update(TABLE_NAME, values, "waybill = ?", new String[]{wayBill}) > 0) {
                result = true;
            } else {
                result = false;
            }
            database.close();
            return result;
        }
    }

    public List<Map<String, String>> query(String wayBill) {
        List<Map<String, String>> list;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            list = new ArrayList<>();
            if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
                Cursor cursor = database.query(TABLE_NAME, null, "waybill=?", new String[]{wayBill}, null, null, null);
                int waybillIndex = cursor.getColumnIndex("waybill");
                int dateIndex = cursor.getColumnIndex("date");
                while (cursor.moveToNext()) {
                    Map<String, String> map = new HashMap<>();
                    map.put("waybill", cursor.getString(waybillIndex));
                    map.put("date", cursor.getString(dateIndex));
                    list.add(map);
                }
                database.close();
            }
        }
        return list;
    }

    public List<Map<String, String>> query() {
        List<Map<String, String>> list;
        SQLiteDatabase database;
        synchronized (DatabaseCreate.LOCK) {
            list = new ArrayList<>();
            if (this.mHelp != null && (database = this.mHelp.getWritableDatabase()) != null) {
                Cursor cursor = database.query(TABLE_NAME, null, null, null, null, null, "date desc");
                int waybillIndex = cursor.getColumnIndex("waybill");
                int dateIndex = cursor.getColumnIndex("date");
                while (cursor.moveToNext()) {
                    Map<String, String> map = new HashMap<>();
                    map.put("waybill", cursor.getString(waybillIndex));
                    map.put("date", cursor.getString(dateIndex));
                    list.add(map);
                }
                database.close();
            }
        }
        return list;
    }

    public void clearTable() {
        synchronized (DatabaseCreate.LOCK) {
            SQLiteDatabase database = this.mHelp.getWritableDatabase();
            if (database != null) {
                database.execSQL("delete from waybill_history");
                database.close();
            }
        }
    }

    private ContentValues warpValues(String wayBill, String date) {
        if (wayBill == null || date == null) {
            return null;
        }
        ContentValues values = new ContentValues();
        values.put("waybill", wayBill);
        values.put("date", date);
        return values;
    }
}
