package cn.beekee.zhongtong.fragment;

import android.app.Fragment;
import android.content.Intent;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.text.format.DateUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ListView;
import android.widget.SimpleAdapter;
import cn.beekee.zhongtong.R;
import cn.beekee.zhongtong.fragment.main.ActivityNewsInfo;
import cn.beekee.zhongtong.util.StaticParam;
import cn.beekee.zhongtong.util.SweetDialogCreator;
import cn.beekee.zhongtong.util.net.JsonOperate;
import cn.beekee.zhongtong.util.net.NetTaskManager;
import cn.beekee.zhongtong.util.net.NetTaskManagerNoDialog;
import com.handmark.pulltorefresh.library.PullToRefreshBase;
import com.handmark.pulltorefresh.library.PullToRefreshListView;
import com.handmark.pulltorefresh.library.extras.SoundPullEventListener;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

public abstract class FragmentNewsList extends Fragment implements AdapterView.OnItemClickListener, NetTaskManager.INetListener, NetTaskManagerNoDialog.INetNoDialogListener {
    SimpleAdapter mAdapter;
    List<Map<String, String>> mListData = new ArrayList();
    PullToRefreshListView mNewsListView;
    int mPage = 1;

    /* access modifiers changed from: protected */
    public abstract NEWS_TYPE getNewsType();

    public enum NEWS_TYPE {
        COMPANY("1"),
        BUSINESS("2");
        
        private String netFlag;

        private NEWS_TYPE(String netFlag2) {
            this.netFlag = netFlag2;
        }

        public String getNetFlag() {
            return this.netFlag;
        }
    }

    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.mAdapter = new SimpleAdapter(getActivity(), this.mListData, R.layout.news_element, new String[]{JsonOperate.NEWS_TITLE, JsonOperate.NEWS_TIME}, new int[]{R.id.text, R.id.news_date});
        getNewsData();
    }

    private void getNewsData() {
        NetTaskManager.getInstance().startTaskGet(getActivity(), StaticParam.NEWS_ZTO_TYPE + getNewsType().getNetFlag() + StaticParam.NEWS_ZTO_PAGE + this.mPage, this);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void getNetDataNoDialog() {
        NetTaskManagerNoDialog.getInstance().startTaskGet(getActivity(), StaticParam.NEWS_ZTO_TYPE + getNewsType().getNetFlag() + StaticParam.NEWS_ZTO_PAGE + this.mPage, this);
    }

    @Nullable
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        this.mNewsListView = (PullToRefreshListView) inflater.inflate(R.layout.news_list, (ViewGroup) null);
        this.mNewsListView.setAdapter(this.mAdapter);
        this.mNewsListView.setOnItemClickListener(this);
        this.mNewsListView.setMode(PullToRefreshBase.Mode.PULL_FROM_END);
        this.mNewsListView.setOnRefreshListener(new PullToRefreshBase.OnRefreshListener<ListView>() {
            /* class cn.beekee.zhongtong.fragment.FragmentNewsList.AnonymousClass1 */

            @Override // com.handmark.pulltorefresh.library.PullToRefreshBase.OnRefreshListener
            public void onRefresh(PullToRefreshBase<ListView> refreshView) {
                refreshView.getLoadingLayoutProxy().setLastUpdatedLabel(DateUtils.formatDateTime(FragmentNewsList.this.getActivity(), System.currentTimeMillis(), 524305));
                FragmentNewsList.this.getNetDataNoDialog();
            }
        });
        SoundPullEventListener<ListView> soundListener = new SoundPullEventListener<>(getActivity());
        soundListener.addSoundEvent(PullToRefreshBase.State.PULL_TO_REFRESH, R.raw.pull_event);
        soundListener.addSoundEvent(PullToRefreshBase.State.RESET, R.raw.reset_sound);
        soundListener.addSoundEvent(PullToRefreshBase.State.REFRESHING, R.raw.refreshing_sound);
        this.mNewsListView.setOnPullEventListener(soundListener);
        return this.mNewsListView;
    }

    @Override // android.widget.AdapterView.OnItemClickListener
    public void onItemClick(AdapterView<?> adapterView, View view, int position, long id) {
        int position2 = position - 1;
        if (position2 >= 0) {
            Intent intent = new Intent(getActivity(), ActivityNewsInfo.class);
            intent.putExtra(ActivityNewsInfo.NEWS_DETAIL_KEY, StaticParam.NEWS_DETAIL + this.mListData.get(position2).get(JsonOperate.NEWS_ID));
            startActivity(intent);
        }
    }

    @Override // cn.beekee.zhongtong.util.net.NetTaskManager.INetListener
    public boolean netResult(int flag, Object result) {
        if (result == null) {
            SweetDialogCreator.showError(getActivity(), StaticParam.NET_SERVICE_FAIL);
            return false;
        }
        for (Map<String, String> map : JsonOperate.decodeNews((String) result)) {
            this.mListData.add(map);
        }
        for (Map<String, String> map2 : this.mListData) {
            String dateDetail = map2.get(JsonOperate.NEWS_TIME);
            String[] dates = dateDetail.split(" ");
            if (dates == null || dates.length <= 0) {
                map2.put(JsonOperate.NEWS_TIME, dateDetail);
            } else {
                map2.put(JsonOperate.NEWS_TIME, dateDetail.split(" ")[0]);
            }
        }
        this.mAdapter.notifyDataSetChanged();
        this.mPage++;
        return true;
    }

    @Override // cn.beekee.zhongtong.util.net.NetTaskManagerNoDialog.INetNoDialogListener
    public boolean netNoDialogResult(int flag, Object result) {
        this.mNewsListView.onRefreshComplete();
        netResult(flag, result);
        return false;
    }
}
