package cn.beekee.zhongtong.fragment.main;

import android.os.Bundle;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;
import cn.beekee.zhongtong.ActivityBase;
import cn.beekee.zhongtong.R;
import cn.beekee.zhongtong.bean.SiteInfoBean;
import cn.beekee.zhongtong.util.SweetDialogCreator;
import com.baidu.location.BDGeofence;
import com.baidu.location.BDLocation;
import com.baidu.location.BDLocationListener;
import com.baidu.location.LocationClient;
import com.baidu.location.LocationClientOption;
import com.baidu.mapapi.map.BaiduMap;
import com.baidu.mapapi.map.BitmapDescriptor;
import com.baidu.mapapi.map.BitmapDescriptorFactory;
import com.baidu.mapapi.map.MapStatusUpdateFactory;
import com.baidu.mapapi.map.MapView;
import com.baidu.mapapi.map.MarkerOptions;
import com.baidu.mapapi.model.LatLng;
import com.baidu.mapapi.overlayutil.DrivingRouteOverlay;
import com.baidu.mapapi.overlayutil.OverlayManager;
import com.baidu.mapapi.overlayutil.TransitRouteOverlay;
import com.baidu.mapapi.overlayutil.WalkingRouteOverlay;
import com.baidu.mapapi.search.core.SearchResult;
import com.baidu.mapapi.search.route.DrivingRoutePlanOption;
import com.baidu.mapapi.search.route.DrivingRouteResult;
import com.baidu.mapapi.search.route.OnGetRoutePlanResultListener;
import com.baidu.mapapi.search.route.PlanNode;
import com.baidu.mapapi.search.route.RoutePlanSearch;
import com.baidu.mapapi.search.route.TransitRoutePlanOption;
import com.baidu.mapapi.search.route.TransitRouteResult;
import com.baidu.mapapi.search.route.WalkingRoutePlanOption;
import com.baidu.mapapi.search.route.WalkingRouteResult;
import java.io.Serializable;

public class ActivityNavigate extends ActivityBase implements View.OnClickListener, OnGetRoutePlanResultListener, BDLocationListener {
    public static final String DATA = "data";
    private BaiduMap mBaiduMap;
    private SiteInfoBean mBean;
    private LocationClient mClient;
    private BitmapDescriptor mDescriptor = BitmapDescriptorFactory.fromResource(R.drawable.icon_mark);
    private LatLng mEndPostionLatLng;
    private MapView mMapView;
    private OverlayManager mOverlayManager;
    private RoutePlanSearch mSearch = null;
    private LatLng mStartPositionLatLng;

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_navigate);
        Serializable serializable = getIntent().getSerializableExtra("data");
        if (serializable == null) {
            Toast.makeText(this, "没有数据，如何导航，阿哼！--怪我喽", 0).show();
            finish();
            return;
        }
        this.mBean = (SiteInfoBean) serializable;
        findViewById(R.id.back).setOnClickListener(this);
        ((TextView) findViewById(R.id.title)).setText(this.mBean.getSiteName() + "网点");
        this.mMapView = (MapView) findViewById(R.id.bmapView);
        this.mBaiduMap = this.mMapView.getMap();
        try {
            this.mEndPostionLatLng = new LatLng(Double.valueOf(this.mBean.getSiteLatitude()).doubleValue(), Double.valueOf(this.mBean.getSiteLongitude()).doubleValue());
            startPosition(this.mEndPostionLatLng);
        } catch (NumberFormatException e) {
            e.printStackTrace();
            SweetDialogCreator.showNormalTip(this, "网点位置有误，来到中通总部吧");
            this.mEndPostionLatLng = new LatLng(31.237628d, 121.21083d);
            startPosition(this.mEndPostionLatLng);
        }
        initLocation();
        this.mSearch = RoutePlanSearch.newInstance();
        this.mSearch.setOnGetRoutePlanResultListener(this);
        findViewById(R.id.drive).setOnClickListener(this);
        findViewById(R.id.transfer).setOnClickListener(this);
        findViewById(R.id.walk).setOnClickListener(this);
    }

    private void initLocation() {
        this.mClient = new LocationClient(this);
        this.mClient.registerLocationListener(this);
        LocationClientOption option = new LocationClientOption();
        option.setOpenGps(true);
        option.setCoorType(BDGeofence.COORD_TYPE_BD09LL);
        option.setScanSpan(1000);
        this.mClient.setLocOption(option);
        this.mClient.start();
    }

    private void startPosition(LatLng latLng) {
        this.mBaiduMap.addOverlay(new MarkerOptions().position(latLng).icon(this.mDescriptor).draggable(false).zIndex(9));
        this.mBaiduMap.animateMapStatus(MapStatusUpdateFactory.newLatLng(latLng));
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.drive:
                searchDrive();
                return;
            case R.id.transfer:
                searchTransfer();
                return;
            case R.id.walk:
                searchWalk();
                return;
            case R.id.back:
                finish();
                return;
            default:
                return;
        }
    }

    private void searchDrive() {
        if (this.mStartPositionLatLng == null) {
            SweetDialogCreator.showWarning(this, "无法查询驾车路径");
        } else {
            this.mSearch.drivingSearch(new DrivingRoutePlanOption().from(PlanNode.withLocation(this.mStartPositionLatLng)).to(PlanNode.withLocation(this.mEndPostionLatLng)));
        }
    }

    private void searchTransfer() {
        if (this.mStartPositionLatLng == null) {
            SweetDialogCreator.showWarning(this, "无法查询换乘路径");
        } else {
            this.mSearch.transitSearch(new TransitRoutePlanOption().from(PlanNode.withLocation(this.mStartPositionLatLng)).to(PlanNode.withLocation(this.mEndPostionLatLng)).city(this.mBean.getSiteCity()));
        }
    }

    private void searchWalk() {
        if (this.mStartPositionLatLng == null) {
            SweetDialogCreator.showWarning(this, "无法查询步行路径");
        } else {
            this.mSearch.walkingSearch(new WalkingRoutePlanOption().from(PlanNode.withLocation(this.mStartPositionLatLng)).to(PlanNode.withLocation(this.mEndPostionLatLng)));
        }
    }

    @Override // com.baidu.location.BDLocationListener
    public void onReceiveLocation(BDLocation bdLocation) {
        if (bdLocation != null) {
            this.mStartPositionLatLng = new LatLng(bdLocation.getLatitude(), bdLocation.getLongitude());
        }
    }

    @Override // com.baidu.mapapi.search.route.OnGetRoutePlanResultListener
    public void onGetDrivingRouteResult(DrivingRouteResult result) {
        if (result == null || result.error != SearchResult.ERRORNO.NO_ERROR) {
            SweetDialogCreator.showWarning(this, "抱歉，未找到结果");
        }
        if (result.error == SearchResult.ERRORNO.NO_ERROR) {
            DrivingRouteOverlay overlay = new DrivingRouteOverlay(this.mBaiduMap);
            overlay.setData(result.getRouteLines().get(0));
            checkFootstep();
            this.mOverlayManager = overlay;
            overlay.addToMap();
            overlay.zoomToSpan();
        }
    }

    @Override // com.baidu.mapapi.search.route.OnGetRoutePlanResultListener
    public void onGetTransitRouteResult(TransitRouteResult result) {
        if (result == null || result.error != SearchResult.ERRORNO.NO_ERROR) {
            SweetDialogCreator.showWarning(this, "抱歉，未找到结果");
        }
        if (result.error == SearchResult.ERRORNO.NO_ERROR) {
            TransitRouteOverlay overlay = new TransitRouteOverlay(this.mBaiduMap);
            overlay.setData(result.getRouteLines().get(0));
            checkFootstep();
            this.mOverlayManager = overlay;
            overlay.addToMap();
            overlay.zoomToSpan();
        }
    }

    @Override // com.baidu.mapapi.search.route.OnGetRoutePlanResultListener
    public void onGetWalkingRouteResult(WalkingRouteResult result) {
        if (result == null || result.error != SearchResult.ERRORNO.NO_ERROR) {
            SweetDialogCreator.showWarning(this, "抱歉，未找到结果");
        }
        if (result.error == SearchResult.ERRORNO.NO_ERROR) {
            WalkingRouteOverlay overlay = new WalkingRouteOverlay(this.mBaiduMap);
            overlay.setData(result.getRouteLines().get(0));
            checkFootstep();
            this.mOverlayManager = overlay;
            overlay.addToMap();
            overlay.zoomToSpan();
        }
    }

    private void checkFootstep() {
        if (this.mOverlayManager != null) {
            this.mOverlayManager.removeFromMap();
            this.mOverlayManager = null;
        }
    }

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onPause() {
        super.onPause();
        this.mMapView.onPause();
    }

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onResume() {
        super.onResume();
        this.mMapView.onResume();
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
        super.onDestroy();
        this.mSearch.destroy();
        this.mClient.stop();
        this.mMapView.onDestroy();
    }
}
