package cn.beekee.zhongtong.fragment.main;

import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ListAdapter;
import android.widget.SimpleAdapter;
import android.widget.TextView;
import cn.beekee.zhongtong.ActivityBase;
import cn.beekee.zhongtong.R;
import cn.beekee.zhongtong.database.DatabaseRangeHistoryHelper;
import cn.beekee.zhongtong.util.AddressPriceSelect;
import cn.beekee.zhongtong.util.DateUtil;
import cn.beekee.zhongtong.util.DeviceUtil;
import cn.beekee.zhongtong.util.DialogHint;
import cn.beekee.zhongtong.util.StaticParam;
import cn.beekee.zhongtong.util.SweetDialogCreator;
import cn.beekee.zhongtong.util.net.JsonOperate;
import cn.beekee.zhongtong.util.net.NetTaskManager;
import com.baoyz.swipemenulistview.SwipeMenu;
import com.baoyz.swipemenulistview.SwipeMenuCreator;
import com.baoyz.swipemenulistview.SwipeMenuItem;
import com.baoyz.swipemenulistview.SwipeMenuListView;
import java.io.Serializable;
import java.util.Date;
import java.util.List;
import java.util.Map;

public class ActivityRangeSearch extends ActivityBase implements View.OnClickListener, AddressPriceSelect.IAddressPriceSelectListener, AdapterView.OnItemClickListener {
    SimpleAdapter mAdapter;
    TextView mAddressText;
    String mCityCode;
    List<Map<String, String>> mListData;
    SwipeMenuListView mListView;
    AddressPriceSelect mSelect;

    /* access modifiers changed from: protected */
    @Override // cn.beekee.zhongtong.ActivityBase
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_rangesearch);
        findViewById(R.id.back).setOnClickListener(this);
        ((TextView) findViewById(R.id.title)).setText("网点查询");
        this.mAddressText = (TextView) findViewById(R.id.address_input);
        this.mAddressText.setOnClickListener(this);
        findViewById(R.id.select).setOnClickListener(this);
        findViewById(R.id.search).setOnClickListener(this);
        findViewById(R.id.clear).setOnClickListener(this);
        this.mListView = (SwipeMenuListView) findViewById(R.id.list);
        this.mListView.setOnItemClickListener(this);
        initListView();
        findViewById(R.id.service).setOnClickListener(this);
        findViewById(R.id.send).setOnClickListener(this);
    }

    private void initListView() {
        this.mListView.setMenuCreator(new SwipeMenuCreator() {
            /* class cn.beekee.zhongtong.fragment.main.ActivityRangeSearch.AnonymousClass1 */

            @Override // com.baoyz.swipemenulistview.SwipeMenuCreator
            public void create(SwipeMenu menu) {
                SwipeMenuItem deleteItem = new SwipeMenuItem(ActivityRangeSearch.this.getApplicationContext());
                deleteItem.setBackground(new ColorDrawable(Color.rgb(249, 63, 37)));
                deleteItem.setWidth(DeviceUtil.dp2px(ActivityRangeSearch.this, 90));
                deleteItem.setIcon(R.drawable.trash);
                menu.addMenuItem(deleteItem);
            }
        });
        this.mListView.setOnMenuItemClickListener(new SwipeMenuListView.OnMenuItemClickListener() {
            /* class cn.beekee.zhongtong.fragment.main.ActivityRangeSearch.AnonymousClass2 */

            @Override // com.baoyz.swipemenulistview.SwipeMenuListView.OnMenuItemClickListener
            public boolean onMenuItemClick(int position, SwipeMenu menu, int index) {
                if (ActivityRangeSearch.this.mListData != null) {
                    switch (index) {
                        case 0:
                            ActivityRangeSearch.this.performDelete(position);
                            break;
                    }
                }
                return false;
            }
        });
    }

    /* access modifiers changed from: protected */
    public void onStart() {
        super.onStart();
        this.mListData = DatabaseRangeHistoryHelper.getInstance(this).query();
        this.mAdapter = new SimpleAdapter(this, this.mListData, R.layout.item_listview_address_slip, new String[]{"address", "date"}, new int[]{R.id.address, R.id.date});
        this.mListView.setAdapter((ListAdapter) this.mAdapter);
    }

    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.clear:
                if (hasHistory()) {
                    clearAll();
                    return;
                } else {
                    SweetDialogCreator.showNormalTip(this, "没有历史记录");
                    return;
                }
            case R.id.address_input:
            case R.id.select:
                selectAddress();
                return;
            case R.id.search:
                search(this.mCityCode);
                return;
            case R.id.service:
                startActivity(new Intent(this, ActivityServerConnect.class));
                return;
            case R.id.send:
                ActivitySend.send(this);
                return;
            case R.id.back:
                finish();
                return;
            default:
                return;
        }
    }

    private void selectAddress() {
        if (this.mSelect == null) {
            this.mSelect = new AddressPriceSelect(this, this);
        }
        this.mSelect.startSelect();
    }

    private void search(String cityCode) {
        if (TextUtils.isEmpty(cityCode)) {
            SweetDialogCreator.showNormalTip(this, "请先选择城市");
            return;
        }
        NetTaskManager.getInstance().startForceTaskGet(this, StaticParam.SITE_LIST_GET + cityCode, this);
    }

    private boolean hasHistory() {
        return DatabaseRangeHistoryHelper.getInstance(this).query().size() > 0;
    }

    private void clearAll() {
        DialogHint.showDialog(this, "要清空历史纪录吗", new DialogHint.IDialogListener() {
            /* class cn.beekee.zhongtong.fragment.main.ActivityRangeSearch.AnonymousClass3 */

            @Override // cn.beekee.zhongtong.util.DialogHint.IDialogListener
            public void clickOK(boolean ok) {
                if (ok) {
                    ActivityRangeSearch.this.performClearAll();
                }
            }
        });
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void performClearAll() {
        DatabaseRangeHistoryHelper.getInstance(this).clearTable();
        this.mListData.clear();
        this.mAdapter.notifyDataSetChanged();
        SweetDialogCreator.showSuccess(this, "删除成功");
    }

    @Override // cn.beekee.zhongtong.util.AddressPriceSelect.IAddressPriceSelectListener
    public void pickAddressPrice(String province, String city, String cityCode) {
        this.mCityCode = cityCode;
        this.mAddressText.setText(province + "  " + city);
    }

    /* access modifiers changed from: protected */
    public void onDestroy() {
        super.onDestroy();
        if (this.mSelect != null) {
            this.mSelect.closeSelect();
        }
    }

    @Override // cn.beekee.zhongtong.util.net.NetTaskManager.INetListener, cn.beekee.zhongtong.ActivityBase
    public boolean netResult(int flag, Object result) {
        if (!super.netResult(flag, result)) {
            return false;
        }
        List<Map<String, String>> list = JsonOperate.decodeSiteList((String) result);
        if (list.size() == 0) {
            SweetDialogCreator.showWarning(this, StaticParam.NET_SERVICE_DATA_NOT);
            return false;
        }
        if (DatabaseRangeHistoryHelper.getInstance(this).query(this.mCityCode).size() == 0) {
            DatabaseRangeHistoryHelper.getInstance(this).insert(this.mAddressText.getText().toString(), this.mCityCode, DateUtil.orderFormat(new Date()));
        } else {
            DatabaseRangeHistoryHelper.getInstance(this).update(this.mAddressText.getText().toString(), this.mCityCode, DateUtil.orderFormat(new Date()));
        }
        Intent intent = new Intent(this, ActivitySiteList.class);
        Bundle bundle = new Bundle();
        bundle.putSerializable(ActivitySiteList.SITE_LIST_KEY, (Serializable) list);
        intent.putExtras(bundle);
        startActivity(intent);
        return true;
    }

    @Override // android.widget.AdapterView.OnItemClickListener
    public void onItemClick(AdapterView<?> adapterView, View view, int position, long id) {
        this.mCityCode = this.mListData.get(position).get(DatabaseRangeHistoryHelper.CODE_KEY);
        this.mAddressText.setText(this.mListData.get(position).get("address"));
        search(this.mCityCode);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void performDelete(int position) {
        if (DatabaseRangeHistoryHelper.getInstance(this).delete(this.mListData.get(position).get(DatabaseRangeHistoryHelper.CODE_KEY))) {
            SweetDialogCreator.showSuccess(this, "删除成功");
            this.mListData.remove(position);
            this.mAdapter.notifyDataSetChanged();
            return;
        }
        SweetDialogCreator.showError(this, "删除失败");
    }
}
