package cn.beekee.zhongtong.util;

import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.net.Uri;
import android.os.AsyncTask;
import android.util.Log;
import android.widget.Toast;
import cn.beekee.zhongtong.bean.UpdateCheckBean;
import cn.beekee.zhongtong.util.net.NetDownAsyncTask;
import cn.beekee.zhongtong.util.net.NetStatus;
import cn.beekee.zhongtong.util.net.NetUpdateApkAsyncTask;
import cn.pedant.SweetAlert.SweetAlertDialog;
import java.io.File;
import java.io.IOException;

public class UpdateCheck implements NetUpdateApkAsyncTask.IUpdateListener, NetDownAsyncTask.IDownFileListener {
    Context mContext;
    SweetAlertDialog mDialog;
    String mFileName = "zto.apk";
    File mToFile;
    UpdateCheckBean mUpdateBean;

    public static void updateApk(Context context) {
        new UpdateCheck(context).startCheck();
    }

    private UpdateCheck(Context context) {
        this.mContext = context;
    }

    private void startCheck() {
        if (!NetStatus.isConnect(this.mContext)) {
            SweetDialogCreator.notNetTip(this.mContext);
            return;
        }
        final NetUpdateApkAsyncTask task = new NetUpdateApkAsyncTask(this.mContext, this);
        task.execute(new Void[0]);
        this.mDialog = SweetDialogCreator.getLoadingDialog(this.mContext);
        this.mDialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
            /* class cn.beekee.zhongtong.util.UpdateCheck.AnonymousClass1 */

            public void onCancel(DialogInterface dialog) {
                dialog.dismiss();
                if (task.getStatus() == AsyncTask.Status.RUNNING) {
                    task.cancel(true);
                }
            }
        });
        this.mDialog.show();
    }

    private void showUpdateDialog() {
        this.mDialog.setTitleText("新版本" + this.mUpdateBean.getVersionName() + "：");
        this.mDialog.setContentText(this.mUpdateBean.getUpdateLog());
        this.mDialog.setCancelText("现在的挺好");
        this.mDialog.setConfirmText("体验新功能").setConfirmClickListener(new SweetAlertDialog.OnSweetClickListener() {
            /* class cn.beekee.zhongtong.util.UpdateCheck.AnonymousClass2 */

            @Override // cn.pedant.SweetAlert.SweetAlertDialog.OnSweetClickListener
            public void onClick(SweetAlertDialog sweetAlertDialog) {
                sweetAlertDialog.dismissWithAnimation();
                if (UpdateCheck.this.createFile()) {
                    NetDownAsyncTask.getDefaultDown(UpdateCheck.this.mContext, UpdateCheck.this.mUpdateBean.getApkUrl(), UpdateCheck.this.mToFile, UpdateCheck.this).execute(new Void[0]);
                }
            }
        });
        this.mDialog.changeAlertType(0);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean createFile() {
        this.mToFile = new FileUtil().getCacheFile(this.mFileName);
        if (this.mToFile == null) {
            Toast.makeText(this.mContext, "哈哈，手机存储设备有问题，更新不了了", 0).show();
            return false;
        }
        if (this.mToFile.exists()) {
            this.mToFile.delete();
        }
        try {
            this.mToFile.createNewFile();
            return true;
        } catch (IOException e) {
            e.printStackTrace();
            Toast.makeText(this.mContext, "哈哈，手机存储设备有问题，更新不了了", 0).show();
            return false;
        }
    }

    @Override // cn.beekee.zhongtong.util.net.NetDownAsyncTask.IDownFileListener
    public void downProgress(int progress) {
        switch (progress) {
            case -4:
            case -3:
            case -2:
            case -1:
                return;
            default:
                if (progress == 100) {
                    installApk();
                    return;
                }
                return;
        }
    }

    private void installApk() {
        Intent intent = new Intent("android.intent.action.VIEW");
        intent.addFlags(268435456);
        intent.setDataAndType(Uri.fromFile(this.mToFile), "application/vnd.android.package-archive");
        this.mContext.startActivity(intent);
    }

    @Override // cn.beekee.zhongtong.util.net.NetUpdateApkAsyncTask.IUpdateListener
    public void checkBean(UpdateCheckBean checkBean) {
        this.mUpdateBean = checkBean;
        Log.e("", "bean:" + this.mUpdateBean);
        if (checkBean == null) {
            this.mDialog.setTitleText("连接服务器异常，请稍后再试");
            this.mDialog.changeAlertType(3);
            this.mDialog.setConfirmText("OK");
            return;
        }
        if (DeviceUtil.getVersionName(this.mContext).compareTo(this.mUpdateBean.getVersionName()) < 0) {
            showUpdateDialog();
        } else {
            this.mDialog.setTitleText("棒棒哒!").setContentText("已是最新版本:" + this.mUpdateBean.getVersionName()).changeAlertType(2);
        }
    }
}
