package cn.beekee.zhongtong.util.net;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class JsonOrder {
    public static final String KEY = "WkhPTkdUT05HS1VBSURJQVBQ";

    public static String getDigest() {
        return KEY;
    }

    public static CreateJson createJson(String orderCode, String partnerCode, String userId, String name, String phone, String province, String city, String district, String address, String startTime, String remark) {
        return new CreateJson(orderCode, partnerCode, userId, name, phone, province, city, district, address, startTime, remark);
    }

    public static UpdateJson updateJson(String orderCode, String fieldName, String fieldValue, String reason) {
        return new UpdateJson(orderCode, fieldName, fieldValue, reason);
    }

    public static SearchJson searchJson(String userId, String startTime, String endTime, String pageSize, String pageIndex) {
        return new SearchJson(userId, startTime, endTime, pageSize, pageIndex);
    }

    public static SearchDetailJson searchDetail(String userId, String orderCode) {
        return new SearchDetailJson(userId, orderCode);
    }

    public static PriceJson priceJson(String sendProv, String sendCity, String dispProv, String dispCity) {
        return new PriceJson(sendProv, sendCity, dispProv, dispCity);
    }

    public static class CreateJson {
        private final String mAddress;
        private final String mCity;
        private final String mDistrict;
        private JSONObject mJsonObject;
        private final String mName;
        private final String mOrderCode;
        private final String mPartnerCode;
        private final String mPhone;
        private final String mProvince;
        private final String mRemark;
        private final String mStartTime;
        private final String mUserId;

        public CreateJson(String orderCode, String partnerCode, String userId, String name, String phone, String province, String city, String district, String address, String startTime, String remark) {
            this.mOrderCode = orderCode;
            this.mPartnerCode = partnerCode;
            this.mUserId = userId;
            this.mName = name;
            this.mPhone = phone;
            this.mProvince = province;
            this.mCity = city;
            this.mDistrict = district;
            this.mAddress = address;
            this.mStartTime = startTime;
            this.mRemark = remark;
        }

        public String toJsonString() {
            toJsonObject();
            if (this.mJsonObject == null) {
                return null;
            }
            return this.mJsonObject.toString();
        }

        private void toJsonObject() {
            if (this.mJsonObject == null) {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(JsonOperate.ORDER_CODE, this.mOrderCode);
                    jsonObject.put("partnerCode", this.mPartnerCode);
                    jsonObject.put("starttime", this.mStartTime);
                    jsonObject.put("remark", this.mRemark);
                    JSONObject senderObject = new JSONObject();
                    senderObject.put(JsonOperate.NEWS_ID, this.mUserId);
                    senderObject.put(JsonOperate.ORDER_NAME, this.mName);
                    senderObject.put(JsonOperate.ORDER_PHONE, this.mPhone);
                    senderObject.put("prov", this.mProvince);
                    senderObject.put("city", this.mCity);
                    senderObject.put("county", this.mDistrict);
                    senderObject.put("address", this.mAddress);
                    jsonObject.put("sender", senderObject);
                    this.mJsonObject = jsonObject;
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static class UpdateJson {
        public static final String FIELD_BILL_CODE = "billCode";
        public static final String FIELD_STATUS = "status";
        public static final String VALUE_STATUS_CANCEL = "cancel";
        private final String mFieldName;
        private final String mFieldValue;
        private JSONArray mJsonArray;
        private final String mOrderCode;
        private final String mReason;

        public UpdateJson(String orderCode, String fieldName, String fieldValue, String reason) {
            this.mOrderCode = orderCode;
            this.mFieldName = fieldName;
            this.mFieldValue = fieldValue;
            this.mReason = reason;
        }

        public String toJsonString() {
            toJsonObject();
            if (this.mJsonArray == null) {
                return null;
            }
            return this.mJsonArray.toString();
        }

        private void toJsonObject() {
            if (this.mJsonArray == null) {
                try {
                    JSONArray jsonArray = new JSONArray();
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put(JsonOperate.ORDER_CODE, this.mOrderCode);
                    jsonObject.put("fieldName", this.mFieldName);
                    jsonObject.put("fieldValue", this.mFieldValue);
                    jsonObject.put(JsonOperate.ORDER_REASON, this.mReason);
                    jsonArray.put(jsonObject);
                    this.mJsonArray = jsonArray;
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static class SearchJson {
        private final String mEndTime;
        private JSONObject mJsonObject;
        private final String mPageIndex;
        private final String mPageSize;
        private final String mStartTime;
        private String mStatus;
        private final String mUserId;

        public SearchJson(String userId, String startTime, String endTime, String pageSize, String pageIndex) {
            this.mUserId = userId;
            this.mStartTime = startTime;
            this.mEndTime = endTime;
            this.mPageSize = pageSize;
            this.mPageIndex = pageIndex;
        }

        public void setStatus(String status) {
            this.mStatus = status;
        }

        public String toJsonString() {
            toJsonObject();
            if (this.mJsonObject == null) {
                return null;
            }
            return this.mJsonObject.toString();
        }

        private void toJsonObject() {
            if (this.mJsonObject == null) {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("sendId", this.mUserId);
                    jsonObject.put("starttime", this.mStartTime);
                    jsonObject.put("endtime", this.mEndTime);
                    if (this.mStatus != null) {
                        jsonObject.put("status", this.mStatus);
                    }
                    jsonObject.put("pageSize", this.mPageSize);
                    jsonObject.put("pageIndex", this.mPageIndex);
                    this.mJsonObject = jsonObject;
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public static class SearchDetailJson {
        private JSONObject mJsonObject;
        private final String mOrderCode;
        private final String mUserId;

        public SearchDetailJson(String userId, String orderCode) {
            this.mUserId = userId;
            this.mOrderCode = orderCode;
        }

        public String toJsonString() {
            toJsonObject();
            if (this.mJsonObject == null) {
                return null;
            }
            return this.mJsonObject.toString();
        }

        private void toJsonObject() {
            if (this.mJsonObject == null) {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("sendId", this.mUserId);
                    JSONArray array = new JSONArray();
                    array.put(this.mOrderCode);
                    jsonObject.put(JsonOperate.ORDER_CODE, array);
                    this.mJsonObject = jsonObject;
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }
    }

    public class WayBillSearchJson {
        public WayBillSearchJson() {
        }
    }

    public class SiteAssignJson {
        public SiteAssignJson() {
        }
    }

    public static class PriceJson {
        private final String dispCity;
        private final String dispProv;
        private JSONObject mJsonObject;
        private final String sendCity;
        private final String sendProv;

        public PriceJson(String sendProv2, String sendCity2, String dispProv2, String dispCity2) {
            this.sendProv = sendProv2;
            this.sendCity = sendCity2;
            this.dispProv = dispProv2;
            this.dispCity = dispCity2;
        }

        public String toJsonString() {
            toJsonObject();
            if (this.mJsonObject == null) {
                return null;
            }
            return this.mJsonObject.toString();
        }

        private void toJsonObject() {
            if (this.mJsonObject == null) {
                try {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.put("sendProv", this.sendProv);
                    jsonObject.put("sendCity", this.sendCity);
                    jsonObject.put("dispProv", this.dispProv);
                    jsonObject.put("dispCity", this.dispCity);
                    this.mJsonObject = jsonObject;
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }
    }
}
