package cn.beekee.zhongtong.util.net;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.support.v7.internal.widget.ActivityChooserView;
import cn.beekee.zhongtong.util.SweetDialogCreator;
import cn.beekee.zhongtong.util.net.NetAsyncTask;
import java.util.HashMap;
import java.util.Map;

public class NetTaskManager implements NetAsyncTask.IAsyncListener {
    private static int KEY = 0;
    public static final int NET_UN_LINK = -1;
    private static NetTaskManager mManager = new NetTaskManager();
    private static Map<Integer, TaskHelper> mMap = new HashMap();

    public interface INetListener {
        boolean netResult(int i, Object obj);
    }

    private NetTaskManager() {
    }

    public static NetTaskManager getInstance() {
        return mManager;
    }

    public int startTaskGet(Context context, String urlString, INetListener listener) {
        if (!judgeNet(context)) {
            return -1;
        }
        initFlag();
        NetAsyncTask task = new NetAsyncTask(KEY, false, urlString, this);
        mMap.put(Integer.valueOf(KEY), new TaskHelper(task, listener, context));
        task.execute(new String[0]);
        return KEY;
    }

    public int startForceTaskGet(Context context, String urlString, INetListener listener) {
        cancelAll();
        return startTaskGet(context, urlString, listener);
    }

    public int startTaskPost(Context context, String urlString, String dataString, INetListener listener) {
        if (!judgeNet(context)) {
            return -1;
        }
        initFlag();
        NetAsyncTask task = new NetAsyncTask(KEY, true, urlString, this);
        mMap.put(Integer.valueOf(KEY), new TaskHelper(task, listener, context));
        task.execute(dataString);
        return KEY;
    }

    public int startForceTaskPost(Context context, String urlString, String dataString, INetListener listener) {
        cancelAll();
        return startTaskPost(context, urlString, dataString, listener);
    }

    public void startLinkPost(String link, String data) {
        initFlag();
        new NetAsyncTask(KEY, true, link, null).execute(data);
    }

    private void initFlag() {
        int i = KEY + 1;
        KEY = i;
        KEY = i % ActivityChooserView.ActivityChooserViewAdapter.MAX_ACTIVITY_COUNT_UNLIMITED;
    }

    private boolean judgeNet(Context context) {
        if (NetStatus.isConnect(context)) {
            return true;
        }
        SweetDialogCreator.notNetTip(context);
        return false;
    }

    public void cancel(int flag) {
        if (!(mMap.get(Integer.valueOf(flag)) == null || mMap.get(Integer.valueOf(flag)).mTask == null)) {
            mMap.get(Integer.valueOf(flag)).mTask.cancel(true);
        }
        removeTask(flag);
    }

    public void cancelAll() {
        for (Integer flag : mMap.keySet()) {
            cancel(flag.intValue());
        }
    }

    private void removeTask(int flag) {
        TaskHelper helper = mMap.get(Integer.valueOf(flag));
        if (helper != null) {
            if (helper.mDialog != null && helper.mDialog.isShowing()) {
                helper.mDialog.dismiss();
            }
            mMap.remove(Integer.valueOf(flag));
        }
    }

    @Override // cn.beekee.zhongtong.util.net.NetAsyncTask.IAsyncListener
    public void onNetStart(final int flag) {
        TaskHelper helper = mMap.get(Integer.valueOf(flag));
        Dialog dialog = SweetDialogCreator.getLoadingDialog(helper.mContext);
        dialog.setOnCancelListener(new DialogInterface.OnCancelListener() {
            /* class cn.beekee.zhongtong.util.net.NetTaskManager.AnonymousClass1 */

            public void onCancel(DialogInterface dialog) {
                dialog.dismiss();
                NetTaskManager.this.cancel(flag);
            }
        });
        helper.mDialog = dialog;
        dialog.show();
    }

    @Override // cn.beekee.zhongtong.util.net.NetAsyncTask.IAsyncListener
    public void onNetOver(int flag, Object data) {
        TaskHelper helper = mMap.get(Integer.valueOf(flag));
        removeTask(flag);
        if (helper.mTaskListener != null) {
            helper.mTaskListener.netResult(flag, data);
        }
    }

    /* access modifiers changed from: package-private */
    public class TaskHelper {
        final Context mContext;
        Dialog mDialog;
        final NetAsyncTask mTask;
        final INetListener mTaskListener;

        public TaskHelper(NetAsyncTask task, INetListener listenner, Context context) {
            this.mTask = task;
            this.mTaskListener = listenner;
            this.mContext = context;
        }
    }
}
