package cn.beekee.zhongtong.view;

import android.content.Context;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewTreeObserver;
import android.view.animation.DecelerateInterpolator;
import android.widget.ListAdapter;
import android.widget.ListView;
import android.widget.RelativeLayout;
import android.widget.Scroller;
import cn.beekee.zhongtong.R;

public class ZListView extends ListView {
    private static final float OFFSET_RADIO = 2.0f;
    private static final int PULL_LOAD_MORE_DELTA = 100;
    private static final int SCROLLBACK_FOOTER = 1;
    private static final int SCROLLBACK_HEADER = 0;
    private static final int SCROLL_DURATION = 400;
    private boolean enableLoadMore;
    private boolean enableRefresh = true;
    private ZListViewFooter footerView;
    private int headerHeight;
    private ZListViewHeader headerView;
    private RelativeLayout headerViewContent;
    private boolean isFooterAdd = false;
    private boolean isLoadingMore;
    private boolean isRefreashing = false;
    private float lastY;
    private IXListViewListener mListViewListener;
    private int mScrollBack;
    private Scroller scroller;
    private int totalItemCount;

    public interface IXListViewListener {
        void onLoadMore();

        void onRefresh();
    }

    public ZListView(Context context) {
        super(context);
        initView(context);
    }

    public ZListView(Context context, AttributeSet attrs) {
        super(context, attrs);
        initView(context);
    }

    public ZListView(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        initView(context);
    }

    private void initView(Context context) {
        this.scroller = new Scroller(context, new DecelerateInterpolator());
        this.headerView = new ZListViewHeader(context);
        this.footerView = new ZListViewFooter(context);
        this.headerViewContent = (RelativeLayout) this.headerView.findViewById(R.id.xlistview_header_content);
        this.headerView.getViewTreeObserver().addOnGlobalLayoutListener(new ViewTreeObserver.OnGlobalLayoutListener() {
            /* class cn.beekee.zhongtong.view.ZListView.AnonymousClass1 */

            public void onGlobalLayout() {
                ZListView.this.headerHeight = ZListView.this.headerViewContent.getHeight();
                ZListView.this.getViewTreeObserver().removeGlobalOnLayoutListener(this);
            }
        });
        addHeaderView(this.headerView);
    }

    @Override // android.widget.AbsListView, android.widget.ListView
    public void setAdapter(ListAdapter adapter) {
        if (!this.isFooterAdd) {
            this.isFooterAdd = true;
            addFooterView(this.footerView);
        }
        super.setAdapter(adapter);
    }

    public boolean onTouchEvent(MotionEvent ev) {
        this.totalItemCount = getAdapter().getCount();
        switch (ev.getAction()) {
            case 0:
                this.lastY = ev.getRawY();
                break;
            case 1:
                if (getFirstVisiblePosition() != 0) {
                    if (getLastVisiblePosition() == this.totalItemCount - 1) {
                        if (this.enableLoadMore && this.footerView.getBottomMargin() > 100) {
                            startLoadMore();
                        }
                        resetFooterHeight();
                        break;
                    }
                } else {
                    if (this.enableRefresh && this.headerView.getVisiableHeight() > this.headerHeight) {
                        this.isRefreashing = true;
                        this.headerView.setState(2);
                        if (this.mListViewListener != null) {
                            this.mListViewListener.onRefresh();
                        }
                    }
                    resetHeaderHeight();
                    break;
                }
                break;
            case 2:
                float deltaY = ev.getRawY() - this.lastY;
                this.lastY = ev.getRawY();
                if (getFirstVisiblePosition() != 0 || (this.headerView.getVisiableHeight() <= 0 && deltaY <= 0.0f)) {
                    if (getLastVisiblePosition() == this.totalItemCount - 1 && (this.footerView.getBottomMargin() > 0 || deltaY < 0.0f)) {
                        updateFooterHeight((-deltaY) / OFFSET_RADIO);
                        break;
                    }
                } else {
                    updateHeaderHeight(deltaY / OFFSET_RADIO);
                    break;
                }
                break;
        }
        return super.onTouchEvent(ev);
    }

    public void computeScroll() {
        if (this.scroller.computeScrollOffset()) {
            if (this.mScrollBack == 0) {
                this.headerView.setVisiableHeight(this.scroller.getCurrY());
            } else {
                this.footerView.setBottomMargin(this.scroller.getCurrY());
            }
            postInvalidate();
        }
        super.computeScroll();
    }

    public void setPullRefreshEnable(boolean enable) {
        this.enableRefresh = enable;
        if (!this.enableRefresh) {
            this.headerView.hide();
            removeHeaderView(this.headerView);
            return;
        }
        this.headerView.show();
    }

    public void setPullLoadEnable(boolean enable) {
        this.enableLoadMore = enable;
        if (!this.enableLoadMore) {
            this.footerView.hide();
            this.footerView.setOnClickListener(null);
            removeFooterView(this.footerView);
            return;
        }
        this.isLoadingMore = false;
        this.footerView.show();
        this.footerView.setState(0);
        this.footerView.setOnClickListener(new View.OnClickListener() {
            /* class cn.beekee.zhongtong.view.ZListView.AnonymousClass2 */

            public void onClick(View v) {
                ZListView.this.startLoadMore();
            }
        });
    }

    public void stopRefresh() {
        if (this.isRefreashing) {
            this.isRefreashing = false;
            resetHeaderHeight();
        }
    }

    public void stopLoadMore() {
        if (this.isLoadingMore) {
            this.isLoadingMore = false;
            this.footerView.setState(0);
        }
    }

    private void updateHeaderHeight(float delta) {
        this.headerView.setVisiableHeight(((int) delta) + this.headerView.getVisiableHeight());
        if (this.enableRefresh && !this.isRefreashing) {
            if (this.headerView.getVisiableHeight() > this.headerHeight) {
                this.headerView.setState(1);
            } else {
                this.headerView.setState(0);
            }
        }
    }

    private void resetHeaderHeight() {
        int height = this.headerView.getVisiableHeight();
        if ((!this.isRefreashing || height > this.headerHeight) && height != 0) {
            int finalHeight = 0;
            if (this.isRefreashing && height > this.headerHeight) {
                finalHeight = this.headerHeight;
            }
            this.mScrollBack = 0;
            this.scroller.startScroll(0, height, 0, finalHeight - height, SCROLL_DURATION);
            invalidate();
        }
    }

    private void updateFooterHeight(float delta) {
        int height = this.footerView.getBottomMargin() + ((int) delta);
        if (this.enableLoadMore && !this.isLoadingMore) {
            if (height > 100) {
                this.footerView.setState(1);
            } else {
                this.footerView.setState(0);
            }
        }
        this.footerView.setBottomMargin(height);
    }

    private void resetFooterHeight() {
        int bottomMargin = this.footerView.getBottomMargin();
        if (bottomMargin > 0) {
            this.mScrollBack = 1;
            this.scroller.startScroll(0, bottomMargin, 0, -bottomMargin, SCROLL_DURATION);
            invalidate();
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void startLoadMore() {
        this.isLoadingMore = true;
        this.footerView.setState(2);
        if (this.mListViewListener != null) {
            this.mListViewListener.onLoadMore();
        }
    }

    public void setXListViewListener(IXListViewListener l) {
        this.mListViewListener = l;
    }
}
