package cn.beekee.zhongtong.view;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Rect;
import android.support.v4.view.ViewCompat;
import android.support.v4.widget.ViewDragHelper;
import android.util.AttributeSet;
import android.util.Log;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.widget.Adapter;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.FrameLayout;
import android.widget.ListAdapter;
import cn.beekee.zhongtong.R;
import cn.beekee.zhongtong.view.adapter.util.DragEdge;
import cn.beekee.zhongtong.view.adapter.util.OnSwipeLayoutListener;
import cn.beekee.zhongtong.view.adapter.util.ShowMode;
import cn.beekee.zhongtong.view.adapter.util.SwipeListener;
import java.util.ArrayList;
import java.util.List;

@SuppressLint({"ClickableViewAccessibility"})
public class ZSwipeItem extends FrameLayout {
    protected static final String TAG = "ZSwipeItem";
    private GestureDetector gestureDetector;
    private int mDragDistance;
    private DragEdge mDragEdge;
    private ViewDragHelper mDragHelper;
    private ViewDragHelper.Callback mDragHelperCallback;
    private int mEventCounter;
    private float mHorizontalSwipeOffset;
    private List<OnSwipeLayoutListener> mOnLayoutListeners;
    private ShowMode mShowMode;
    private boolean mSwipeEnabled;
    private boolean mTouchConsumedByChild;
    private float mVerticalSwipeOffset;
    private float sX;
    private float sY;
    private List<SwipeListener> swipeListeners;

    public enum Status {
        Middle,
        Open,
        Close
    }

    public ZSwipeItem(Context context) {
        this(context, null);
    }

    public ZSwipeItem(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public ZSwipeItem(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        this.mDragDistance = 0;
        this.mSwipeEnabled = true;
        this.swipeListeners = new ArrayList();
        this.mDragHelperCallback = new ViewDragHelper.Callback() {
            /* class cn.beekee.zhongtong.view.ZSwipeItem.AnonymousClass1 */

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public int clampViewPositionHorizontal(View child, int left, int dx) {
                if (child == ZSwipeItem.this.getSurfaceView()) {
                    switch (AnonymousClass2.$SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[ZSwipeItem.this.mDragEdge.ordinal()]) {
                        case 1:
                        case 2:
                            return ZSwipeItem.this.getPaddingLeft();
                        case 3:
                            if (left < ZSwipeItem.this.getPaddingLeft()) {
                                return ZSwipeItem.this.getPaddingLeft();
                            }
                            if (left > ZSwipeItem.this.getPaddingLeft() + ZSwipeItem.this.mDragDistance) {
                                return ZSwipeItem.this.getPaddingLeft() + ZSwipeItem.this.mDragDistance;
                            }
                            return left;
                        case 4:
                            if (left > ZSwipeItem.this.getPaddingLeft()) {
                                return ZSwipeItem.this.getPaddingLeft();
                            }
                            if (left < ZSwipeItem.this.getPaddingLeft() - ZSwipeItem.this.mDragDistance) {
                                return ZSwipeItem.this.getPaddingLeft() - ZSwipeItem.this.mDragDistance;
                            }
                            return left;
                        default:
                            return left;
                    }
                } else if (child != ZSwipeItem.this.getBottomView()) {
                    return left;
                } else {
                    switch (AnonymousClass2.$SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[ZSwipeItem.this.mDragEdge.ordinal()]) {
                        case 1:
                        case 2:
                            return ZSwipeItem.this.getPaddingLeft();
                        case 3:
                            if (ZSwipeItem.this.mShowMode != ShowMode.PullOut || left <= ZSwipeItem.this.getPaddingLeft()) {
                                return left;
                            }
                            return ZSwipeItem.this.getPaddingLeft();
                        case 4:
                            if (ZSwipeItem.this.mShowMode != ShowMode.PullOut || left >= ZSwipeItem.this.getMeasuredWidth() - ZSwipeItem.this.mDragDistance) {
                                return left;
                            }
                            return ZSwipeItem.this.getMeasuredWidth() - ZSwipeItem.this.mDragDistance;
                        default:
                            return left;
                    }
                }
            }

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public int clampViewPositionVertical(View child, int top, int dy) {
                if (child == ZSwipeItem.this.getSurfaceView()) {
                    switch (AnonymousClass2.$SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[ZSwipeItem.this.mDragEdge.ordinal()]) {
                        case 1:
                            if (top < ZSwipeItem.this.getPaddingTop()) {
                                return ZSwipeItem.this.getPaddingTop();
                            }
                            if (top > ZSwipeItem.this.getPaddingTop() + ZSwipeItem.this.mDragDistance) {
                                return ZSwipeItem.this.getPaddingTop() + ZSwipeItem.this.mDragDistance;
                            }
                            return top;
                        case 2:
                            if (top < ZSwipeItem.this.getPaddingTop() - ZSwipeItem.this.mDragDistance) {
                                return ZSwipeItem.this.getPaddingTop() - ZSwipeItem.this.mDragDistance;
                            }
                            if (top > ZSwipeItem.this.getPaddingTop()) {
                                return ZSwipeItem.this.getPaddingTop();
                            }
                            return top;
                        case 3:
                        case 4:
                            return ZSwipeItem.this.getPaddingTop();
                        default:
                            return top;
                    }
                } else {
                    switch (AnonymousClass2.$SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[ZSwipeItem.this.mDragEdge.ordinal()]) {
                        case 1:
                            if (ZSwipeItem.this.mShowMode == ShowMode.PullOut) {
                                if (top > ZSwipeItem.this.getPaddingTop()) {
                                    return ZSwipeItem.this.getPaddingTop();
                                }
                                return top;
                            } else if (ZSwipeItem.this.getSurfaceView().getTop() + dy < ZSwipeItem.this.getPaddingTop()) {
                                return ZSwipeItem.this.getPaddingTop();
                            } else {
                                if (ZSwipeItem.this.getSurfaceView().getTop() + dy > ZSwipeItem.this.getPaddingTop() + ZSwipeItem.this.mDragDistance) {
                                    return ZSwipeItem.this.getPaddingTop() + ZSwipeItem.this.mDragDistance;
                                }
                                return top;
                            }
                        case 2:
                            if (ZSwipeItem.this.mShowMode == ShowMode.PullOut) {
                                if (top < ZSwipeItem.this.getMeasuredHeight() - ZSwipeItem.this.mDragDistance) {
                                    return ZSwipeItem.this.getMeasuredHeight() - ZSwipeItem.this.mDragDistance;
                                }
                                return top;
                            } else if (ZSwipeItem.this.getSurfaceView().getTop() + dy >= ZSwipeItem.this.getPaddingTop()) {
                                return ZSwipeItem.this.getPaddingTop();
                            } else {
                                if (ZSwipeItem.this.getSurfaceView().getTop() + dy <= ZSwipeItem.this.getPaddingTop() - ZSwipeItem.this.mDragDistance) {
                                    return ZSwipeItem.this.getPaddingTop() - ZSwipeItem.this.mDragDistance;
                                }
                                return top;
                            }
                        case 3:
                        case 4:
                            return ZSwipeItem.this.getPaddingTop();
                        default:
                            return top;
                    }
                }
            }

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public boolean tryCaptureView(View child, int pointerId) {
                return child == ZSwipeItem.this.getSurfaceView() || child == ZSwipeItem.this.getBottomView();
            }

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public int getViewHorizontalDragRange(View child) {
                return ZSwipeItem.this.mDragDistance;
            }

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public int getViewVerticalDragRange(View child) {
                return ZSwipeItem.this.mDragDistance;
            }

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public void onViewReleased(View releasedChild, float xvel, float yvel) {
                super.onViewReleased(releasedChild, xvel, yvel);
                for (SwipeListener l : ZSwipeItem.this.swipeListeners) {
                    l.onHandRelease(ZSwipeItem.this, xvel, yvel);
                }
                if (releasedChild == ZSwipeItem.this.getSurfaceView()) {
                    ZSwipeItem.this.processSurfaceRelease(xvel, yvel);
                } else if (releasedChild == ZSwipeItem.this.getBottomView()) {
                    if (ZSwipeItem.this.getShowMode() == ShowMode.PullOut) {
                        ZSwipeItem.this.processBottomPullOutRelease(xvel, yvel);
                    } else if (ZSwipeItem.this.getShowMode() == ShowMode.LayDown) {
                        ZSwipeItem.this.processBottomLayDownMode(xvel, yvel);
                    }
                }
                ZSwipeItem.this.invalidate();
            }

            @Override // android.support.v4.widget.ViewDragHelper.Callback
            public void onViewPositionChanged(View changedView, int left, int top, int dx, int dy) {
                int evLeft = ZSwipeItem.this.getSurfaceView().getLeft();
                int evTop = ZSwipeItem.this.getSurfaceView().getTop();
                if (changedView == ZSwipeItem.this.getSurfaceView()) {
                    if (ZSwipeItem.this.mShowMode == ShowMode.PullOut) {
                        if (ZSwipeItem.this.mDragEdge == DragEdge.Left || ZSwipeItem.this.mDragEdge == DragEdge.Right) {
                            ZSwipeItem.this.getBottomView().offsetLeftAndRight(dx);
                        } else {
                            ZSwipeItem.this.getBottomView().offsetTopAndBottom(dy);
                        }
                    }
                } else if (changedView == ZSwipeItem.this.getBottomView()) {
                    if (ZSwipeItem.this.mShowMode == ShowMode.PullOut) {
                        ZSwipeItem.this.getSurfaceView().offsetLeftAndRight(dx);
                        ZSwipeItem.this.getSurfaceView().offsetTopAndBottom(dy);
                    } else {
                        Rect rect = ZSwipeItem.this.computeBottomLayDown(ZSwipeItem.this.mDragEdge);
                        ZSwipeItem.this.getBottomView().layout(rect.left, rect.top, rect.right, rect.bottom);
                        int newLeft = ZSwipeItem.this.getSurfaceView().getLeft() + dx;
                        int newTop = ZSwipeItem.this.getSurfaceView().getTop() + dy;
                        if (ZSwipeItem.this.mDragEdge == DragEdge.Left && newLeft < ZSwipeItem.this.getPaddingLeft()) {
                            newLeft = ZSwipeItem.this.getPaddingLeft();
                        } else if (ZSwipeItem.this.mDragEdge == DragEdge.Right && newLeft > ZSwipeItem.this.getPaddingLeft()) {
                            newLeft = ZSwipeItem.this.getPaddingLeft();
                        } else if (ZSwipeItem.this.mDragEdge == DragEdge.Top && newTop < ZSwipeItem.this.getPaddingTop()) {
                            newTop = ZSwipeItem.this.getPaddingTop();
                        } else if (ZSwipeItem.this.mDragEdge == DragEdge.Bottom && newTop > ZSwipeItem.this.getPaddingTop()) {
                            newTop = ZSwipeItem.this.getPaddingTop();
                        }
                        ZSwipeItem.this.getSurfaceView().layout(newLeft, newTop, ZSwipeItem.this.getMeasuredWidth() + newLeft, ZSwipeItem.this.getMeasuredHeight() + newTop);
                    }
                }
                ZSwipeItem.this.dispatchSwipeEvent(evLeft, evTop, dx, dy);
                ZSwipeItem.this.invalidate();
            }
        };
        this.mEventCounter = 0;
        this.mTouchConsumedByChild = false;
        this.sX = -1.0f;
        this.sY = -1.0f;
        this.gestureDetector = new GestureDetector(getContext(), new SwipeDetector());
        this.mDragHelper = ViewDragHelper.create(this, this.mDragHelperCallback);
        TypedArray a = context.obtainStyledAttributes(attrs, R.styleable.ZSwipeItem);
        this.mDragEdge = DragEdge.values()[a.getInt(0, DragEdge.Right.ordinal())];
        this.mShowMode = ShowMode.values()[a.getInt(3, ShowMode.PullOut.ordinal())];
        this.mHorizontalSwipeOffset = a.getDimension(1, 0.0f);
        this.mVerticalSwipeOffset = a.getDimension(2, 0.0f);
        a.recycle();
    }

    /* renamed from: cn.beekee.zhongtong.view.ZSwipeItem$2  reason: invalid class name */
    static /* synthetic */ class AnonymousClass2 {
        static final /* synthetic */ int[] $SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge = new int[DragEdge.values().length];

        static {
            try {
                $SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[DragEdge.Top.ordinal()] = 1;
            } catch (NoSuchFieldError e) {
            }
            try {
                $SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[DragEdge.Bottom.ordinal()] = 2;
            } catch (NoSuchFieldError e2) {
            }
            try {
                $SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[DragEdge.Left.ordinal()] = 3;
            } catch (NoSuchFieldError e3) {
            }
            try {
                $SwitchMap$cn$beekee$zhongtong$view$adapter$util$DragEdge[DragEdge.Right.ordinal()] = 4;
            } catch (NoSuchFieldError e4) {
            }
        }
    }

    /* access modifiers changed from: protected */
    public void dispatchSwipeEvent(int surfaceLeft, int surfaceTop, int dx, int dy) {
        DragEdge edge = getDragEdge();
        boolean open = true;
        if (edge == DragEdge.Left) {
            if (dx < 0) {
                open = false;
            }
        } else if (edge == DragEdge.Right) {
            if (dx > 0) {
                open = false;
            }
        } else if (edge == DragEdge.Top) {
            if (dy < 0) {
                open = false;
            }
        } else if (edge == DragEdge.Bottom && dy > 0) {
            open = false;
        }
        dispatchSwipeEvent(surfaceLeft, surfaceTop, open);
    }

    /* access modifiers changed from: protected */
    public void dispatchSwipeEvent(int surfaceLeft, int surfaceTop, boolean open) {
        safeBottomView();
        Status status = getOpenStatus();
        if (!this.swipeListeners.isEmpty()) {
            Log.d(TAG, "swipeListeners=" + this.swipeListeners.size());
            this.mEventCounter++;
            if (this.mEventCounter == 1) {
                if (open) {
                    this.swipeListeners.get(0).onStartOpen(this);
                    this.swipeListeners.get(this.swipeListeners.size() - 1).onStartOpen(this);
                } else {
                    this.swipeListeners.get(0).onStartClose(this);
                    this.swipeListeners.get(this.swipeListeners.size() - 1).onStartClose(this);
                }
            }
            for (SwipeListener l : this.swipeListeners) {
                l.onUpdate(this, surfaceLeft - getPaddingLeft(), surfaceTop - getPaddingTop());
            }
            if (status == Status.Close) {
                this.swipeListeners.get(0).onClose(this);
                this.swipeListeners.get(this.swipeListeners.size() - 1).onClose(this);
                this.mEventCounter = 0;
            } else if (status == Status.Open) {
                getBottomView().setEnabled(true);
                this.swipeListeners.get(0).onOpen(this);
                this.swipeListeners.get(this.swipeListeners.size() - 1).onOpen(this);
                this.mEventCounter = 0;
            }
        }
    }

    private void safeBottomView() {
        Status status = getOpenStatus();
        ViewGroup bottom = getBottomView();
        if (status == Status.Close) {
            if (bottom.getVisibility() != 4) {
                bottom.setVisibility(4);
            }
        } else if (bottom.getVisibility() != 0) {
            bottom.setVisibility(0);
        }
    }

    public void computeScroll() {
        super.computeScroll();
        if (this.mDragHelper.continueSettling(true)) {
            ViewCompat.postInvalidateOnAnimation(this);
        }
    }

    /* access modifiers changed from: protected */
    @SuppressLint({"WrongCall"})
    public void onLayout(boolean changed, int l, int t, int r, int b) {
        if (getChildCount() != 2) {
            throw new IllegalStateException("You need 2  views in SwipeLayout");
        } else if (!(getChildAt(0) instanceof ViewGroup) || !(getChildAt(1) instanceof ViewGroup)) {
            throw new IllegalArgumentException("The 2 children in SwipeLayout must be an instance of ViewGroup");
        } else {
            if (this.mShowMode == ShowMode.PullOut) {
                layoutPullOut();
            } else if (this.mShowMode == ShowMode.LayDown) {
                layoutLayDown();
            }
            safeBottomView();
            if (this.mOnLayoutListeners != null) {
                for (int i = 0; i < this.mOnLayoutListeners.size(); i++) {
                    this.mOnLayoutListeners.get(i).onLayout(this);
                }
            }
        }
    }

    private void layoutPullOut() {
        Rect rect = computeSurfaceLayoutArea(false);
        getSurfaceView().layout(rect.left, rect.top, rect.right, rect.bottom);
        Rect rect2 = computeBottomLayoutAreaViaSurface(ShowMode.PullOut, rect);
        getBottomView().layout(rect2.left, rect2.top, rect2.right, rect2.bottom);
        bringChildToFront(getSurfaceView());
    }

    private void layoutLayDown() {
        Rect rect = computeSurfaceLayoutArea(false);
        getSurfaceView().layout(rect.left, rect.top, rect.right, rect.bottom);
        Rect rect2 = computeBottomLayoutAreaViaSurface(ShowMode.LayDown, rect);
        getBottomView().layout(rect2.left, rect2.top, rect2.right, rect2.bottom);
        bringChildToFront(getSurfaceView());
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        if (this.mDragEdge == DragEdge.Left || this.mDragEdge == DragEdge.Right) {
            this.mDragDistance = getBottomView().getMeasuredWidth() - dp2px(this.mHorizontalSwipeOffset);
        } else {
            this.mDragDistance = getBottomView().getMeasuredHeight() - dp2px(this.mVerticalSwipeOffset);
        }
    }

    public boolean onInterceptTouchEvent(MotionEvent ev) {
        boolean z = true;
        if (!isEnabled() || !isEnabledInAdapterView()) {
            return true;
        }
        if (!isSwipeEnabled()) {
            return false;
        }
        switch (ev.getActionMasked()) {
            case 0:
                Status status = getOpenStatus();
                if (status != Status.Close) {
                    if (status == Status.Open) {
                        if (childNeedHandleTouchEvent(getBottomView(), ev) == null) {
                            z = false;
                        }
                        this.mTouchConsumedByChild = z;
                        break;
                    }
                } else {
                    if (childNeedHandleTouchEvent(getSurfaceView(), ev) == null) {
                        z = false;
                    }
                    this.mTouchConsumedByChild = z;
                    break;
                }
                break;
            case 1:
            case 3:
                this.mTouchConsumedByChild = false;
                break;
        }
        if (!this.mTouchConsumedByChild) {
            return this.mDragHelper.shouldInterceptTouchEvent(ev);
        }
        return false;
    }

    private View childNeedHandleTouchEvent(ViewGroup v, MotionEvent event) {
        if (v == null) {
            return null;
        }
        if (v.onTouchEvent(event)) {
            return v;
        }
        for (int i = v.getChildCount() - 1; i >= 0; i--) {
            View child = v.getChildAt(i);
            if (child instanceof ViewGroup) {
                View grandChild = childNeedHandleTouchEvent((ViewGroup) child, event);
                if (grandChild != null) {
                    return grandChild;
                }
            } else if (childNeedHandleTouchEvent(v.getChildAt(i), event)) {
                return v.getChildAt(i);
            }
        }
        return null;
    }

    private boolean childNeedHandleTouchEvent(View v, MotionEvent event) {
        if (v == null) {
            return false;
        }
        int[] loc = new int[2];
        v.getLocationOnScreen(loc);
        int left = loc[0];
        int top = loc[1];
        if (event.getRawX() <= ((float) left) || event.getRawX() >= ((float) (v.getWidth() + left)) || event.getRawY() <= ((float) top) || event.getRawY() >= ((float) (v.getHeight() + top))) {
            return false;
        }
        return v.onTouchEvent(event);
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    public boolean onTouchEvent(MotionEvent event) {
        if (!isEnabledInAdapterView() || !isEnabled()) {
            return true;
        }
        if (!isSwipeEnabled()) {
            return super.onTouchEvent(event);
        }
        int action = event.getActionMasked();
        ViewParent parent = getParent();
        this.gestureDetector.onTouchEvent(event);
        Status status = getOpenStatus();
        ViewGroup touching = null;
        if (status == Status.Close) {
            touching = getSurfaceView();
        } else if (status == Status.Open) {
            touching = getBottomView();
        }
        switch (action) {
            case 0:
                this.mDragHelper.processTouchEvent(event);
                parent.requestDisallowInterceptTouchEvent(true);
                this.sX = event.getRawX();
                this.sY = event.getRawY();
                if (touching != null) {
                    touching.setPressed(true);
                }
                return true;
            case 1:
            case 3:
                this.sX = -1.0f;
                this.sY = -1.0f;
                if (touching != null) {
                    touching.setPressed(false);
                }
                parent.requestDisallowInterceptTouchEvent(true);
                this.mDragHelper.processTouchEvent(event);
                break;
            case 2:
                if (this.sX != -1.0f && this.sY != -1.0f) {
                    float distanceX = event.getRawX() - this.sX;
                    float distanceY = event.getRawY() - this.sY;
                    float angle = (float) Math.toDegrees(Math.atan((double) Math.abs(distanceY / distanceX)));
                    boolean doNothing = false;
                    if (this.mDragEdge == DragEdge.Right) {
                        boolean suitable = ((status == Status.Open && (distanceX > 0.0f ? 1 : (distanceX == 0.0f ? 0 : -1)) > 0) || (status == Status.Close && (distanceX > 0.0f ? 1 : (distanceX == 0.0f ? 0 : -1)) < 0)) || status == Status.Middle;
                        if (angle > 30.0f || !suitable) {
                            doNothing = true;
                        }
                    }
                    if (this.mDragEdge == DragEdge.Left) {
                        boolean suitable2 = ((status == Status.Open && (distanceX > 0.0f ? 1 : (distanceX == 0.0f ? 0 : -1)) < 0) || (status == Status.Close && (distanceX > 0.0f ? 1 : (distanceX == 0.0f ? 0 : -1)) > 0)) || status == Status.Middle;
                        if (angle > 30.0f || !suitable2) {
                            doNothing = true;
                        }
                    }
                    if (this.mDragEdge == DragEdge.Top) {
                        boolean suitable3 = ((status == Status.Open && (distanceY > 0.0f ? 1 : (distanceY == 0.0f ? 0 : -1)) < 0) || (status == Status.Close && (distanceY > 0.0f ? 1 : (distanceY == 0.0f ? 0 : -1)) > 0)) || status == Status.Middle;
                        if (angle < 60.0f || !suitable3) {
                            doNothing = true;
                        }
                    }
                    if (this.mDragEdge == DragEdge.Bottom) {
                        boolean suitable4 = ((status == Status.Open && (distanceY > 0.0f ? 1 : (distanceY == 0.0f ? 0 : -1)) > 0) || (status == Status.Close && (distanceY > 0.0f ? 1 : (distanceY == 0.0f ? 0 : -1)) < 0)) || status == Status.Middle;
                        if (angle < 60.0f || !suitable4) {
                            doNothing = true;
                        }
                    }
                    if (!doNothing) {
                        if (touching != null) {
                            touching.setPressed(false);
                        }
                        parent.requestDisallowInterceptTouchEvent(true);
                        this.mDragHelper.processTouchEvent(event);
                        break;
                    } else {
                        parent.requestDisallowInterceptTouchEvent(false);
                        return false;
                    }
                } else {
                    event.setAction(0);
                    this.mDragHelper.processTouchEvent(event);
                    parent.requestDisallowInterceptTouchEvent(true);
                    this.sX = event.getRawX();
                    this.sY = event.getRawY();
                    return true;
                }
                break;
            default:
                parent.requestDisallowInterceptTouchEvent(true);
                this.mDragHelper.processTouchEvent(event);
                break;
        }
        return true;
    }

    private boolean isEnabledInAdapterView() {
        Adapter adapter;
        AdapterView adapterView = getAdapterView();
        if (adapterView == null || (adapter = adapterView.getAdapter()) == null) {
            return true;
        }
        int p = adapterView.getPositionForView(this);
        if (adapter instanceof BaseAdapter) {
            return ((BaseAdapter) adapter).isEnabled(p);
        }
        if (adapter instanceof ListAdapter) {
            return ((ListAdapter) adapter).isEnabled(p);
        }
        return true;
    }

    public void setSwipeEnabled(boolean enabled) {
        this.mSwipeEnabled = enabled;
    }

    public boolean isSwipeEnabled() {
        return this.mSwipeEnabled;
    }

    private AdapterView getAdapterView() {
        for (ViewParent t = getParent(); t != null; t = t.getParent()) {
            if (t instanceof AdapterView) {
                return (AdapterView) t;
            }
        }
        return null;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void performAdapterViewItemClick(MotionEvent e) {
        Log.d(TAG, "performAdapterViewItemClick()");
        for (ViewParent t = getParent(); t != null; t = t.getParent()) {
            if (t instanceof AdapterView) {
                AdapterView view = (AdapterView) t;
                int p = view.getPositionForView(this);
                if (p != -1 && view.performItemClick(view.getChildAt(p - view.getFirstVisiblePosition()), p, view.getAdapter().getItemId(p))) {
                    return;
                }
            } else if ((t instanceof View) && ((View) t).performClick()) {
                return;
            }
        }
    }

    private class SwipeDetector extends GestureDetector.SimpleOnGestureListener {
        private SwipeDetector() {
        }

        public boolean onDown(MotionEvent e) {
            return true;
        }

        public boolean onSingleTapUp(MotionEvent e) {
            ZSwipeItem.this.performAdapterViewItemClick(e);
            return true;
        }

        public boolean onSingleTapConfirmed(MotionEvent e) {
            return false;
        }

        public void onLongPress(MotionEvent e) {
            ZSwipeItem.this.performLongClick();
        }

        public boolean onDoubleTap(MotionEvent e) {
            return false;
        }
    }

    public void setDragEdge(DragEdge dragEdge) {
        this.mDragEdge = dragEdge;
        requestLayout();
    }

    public void setShowMode(ShowMode mode) {
        this.mShowMode = mode;
        requestLayout();
    }

    public DragEdge getDragEdge() {
        return this.mDragEdge;
    }

    public int getDragDistance() {
        return this.mDragDistance;
    }

    public ShowMode getShowMode() {
        return this.mShowMode;
    }

    public ViewGroup getSurfaceView() {
        return (ViewGroup) getChildAt(1);
    }

    public ViewGroup getBottomView() {
        return (ViewGroup) getChildAt(0);
    }

    public Status getOpenStatus() {
        int surfaceLeft = getSurfaceView().getLeft();
        int surfaceTop = getSurfaceView().getTop();
        if (surfaceLeft == getPaddingLeft() && surfaceTop == getPaddingTop()) {
            return Status.Close;
        }
        if (surfaceLeft == getPaddingLeft() - this.mDragDistance || surfaceLeft == getPaddingLeft() + this.mDragDistance || surfaceTop == getPaddingTop() - this.mDragDistance || surfaceTop == getPaddingTop() + this.mDragDistance) {
            return Status.Open;
        }
        return Status.Middle;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void processSurfaceRelease(float xvel, float yvel) {
        if (xvel == 0.0f && getOpenStatus() == Status.Middle) {
            close();
        }
        if (this.mDragEdge == DragEdge.Left || this.mDragEdge == DragEdge.Right) {
            if (xvel > 0.0f) {
                if (this.mDragEdge == DragEdge.Left) {
                    open();
                } else {
                    close();
                }
            }
            if (xvel >= 0.0f) {
                return;
            }
            if (this.mDragEdge == DragEdge.Left) {
                close();
            } else {
                open();
            }
        } else {
            if (yvel > 0.0f) {
                if (this.mDragEdge == DragEdge.Top) {
                    open();
                } else {
                    close();
                }
            }
            if (yvel >= 0.0f) {
                return;
            }
            if (this.mDragEdge == DragEdge.Top) {
                close();
            } else {
                open();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void processBottomPullOutRelease(float xvel, float yvel) {
        if (xvel == 0.0f && getOpenStatus() == Status.Middle) {
            close();
        }
        if (this.mDragEdge == DragEdge.Left || this.mDragEdge == DragEdge.Right) {
            if (xvel > 0.0f) {
                if (this.mDragEdge == DragEdge.Left) {
                    open();
                } else {
                    close();
                }
            }
            if (xvel >= 0.0f) {
                return;
            }
            if (this.mDragEdge == DragEdge.Left) {
                close();
            } else {
                open();
            }
        } else {
            if (yvel > 0.0f) {
                if (this.mDragEdge == DragEdge.Top) {
                    open();
                } else {
                    close();
                }
            }
            if (yvel >= 0.0f) {
                return;
            }
            if (this.mDragEdge == DragEdge.Top) {
                close();
            } else {
                open();
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void processBottomLayDownMode(float xvel, float yvel) {
        if (xvel == 0.0f && getOpenStatus() == Status.Middle) {
            close();
        }
        int l = getPaddingLeft();
        int t = getPaddingTop();
        if (xvel < 0.0f && this.mDragEdge == DragEdge.Right) {
            l -= this.mDragDistance;
        }
        if (xvel > 0.0f && this.mDragEdge == DragEdge.Left) {
            l += this.mDragDistance;
        }
        if (yvel > 0.0f && this.mDragEdge == DragEdge.Top) {
            t += this.mDragDistance;
        }
        if (yvel < 0.0f && this.mDragEdge == DragEdge.Bottom) {
            t -= this.mDragDistance;
        }
        this.mDragHelper.smoothSlideViewTo(getSurfaceView(), l, t);
        invalidate();
    }

    public void open() {
        open(true, true);
    }

    public void open(boolean smooth) {
        open(smooth, true);
    }

    public void open(boolean smooth, boolean notify) {
        ViewGroup surface = getSurfaceView();
        ViewGroup bottom = getBottomView();
        Rect rect = computeSurfaceLayoutArea(true);
        if (smooth) {
            this.mDragHelper.smoothSlideViewTo(getSurfaceView(), rect.left, rect.top);
        } else {
            int dx = rect.left - surface.getLeft();
            int dy = rect.top - surface.getTop();
            surface.layout(rect.left, rect.top, rect.right, rect.bottom);
            if (getShowMode() == ShowMode.PullOut) {
                Rect bRect = computeBottomLayoutAreaViaSurface(ShowMode.PullOut, rect);
                bottom.layout(bRect.left, bRect.top, bRect.right, bRect.bottom);
            }
            if (notify) {
                dispatchSwipeEvent(rect.left, rect.top, dx, dy);
            } else {
                safeBottomView();
            }
        }
        invalidate();
    }

    public void close() {
        close(true, true);
    }

    public void close(boolean smooth) {
        close(smooth, true);
    }

    public void close(boolean smooth, boolean notify) {
        ViewGroup surface = getSurfaceView();
        if (smooth) {
            this.mDragHelper.smoothSlideViewTo(getSurfaceView(), getPaddingLeft(), getPaddingTop());
        } else {
            Rect rect = computeSurfaceLayoutArea(false);
            int dx = rect.left - surface.getLeft();
            int dy = rect.top - surface.getTop();
            surface.layout(rect.left, rect.top, rect.right, rect.bottom);
            if (notify) {
                dispatchSwipeEvent(rect.left, rect.top, dx, dy);
            } else {
                safeBottomView();
            }
        }
        invalidate();
    }

    public void toggle() {
        toggle(true);
    }

    public void toggle(boolean smooth) {
        if (getOpenStatus() == Status.Open) {
            close(smooth);
        } else if (getOpenStatus() == Status.Close) {
            open(smooth);
        }
    }

    private Rect computeSurfaceLayoutArea(boolean open) {
        int l = getPaddingLeft();
        int t = getPaddingTop();
        if (open) {
            if (this.mDragEdge == DragEdge.Left) {
                l = getPaddingLeft() + this.mDragDistance;
            } else if (this.mDragEdge == DragEdge.Right) {
                l = getPaddingLeft() - this.mDragDistance;
            } else {
                t = this.mDragEdge == DragEdge.Top ? getPaddingTop() + this.mDragDistance : getPaddingTop() - this.mDragDistance;
            }
        }
        return new Rect(l, t, getMeasuredWidth() + l, getMeasuredHeight() + t);
    }

    private Rect computeBottomLayoutAreaViaSurface(ShowMode mode, Rect surfaceArea) {
        int bl = surfaceArea.left;
        int bt = surfaceArea.top;
        int br = surfaceArea.right;
        int bb = surfaceArea.bottom;
        if (mode == ShowMode.PullOut) {
            if (this.mDragEdge == DragEdge.Left) {
                bl = surfaceArea.left - this.mDragDistance;
            } else if (this.mDragEdge == DragEdge.Right) {
                bl = surfaceArea.right;
            } else {
                bt = this.mDragEdge == DragEdge.Top ? surfaceArea.top - this.mDragDistance : surfaceArea.bottom;
            }
            if (this.mDragEdge == DragEdge.Left || this.mDragEdge == DragEdge.Right) {
                bb = surfaceArea.bottom;
                br = bl + getBottomView().getMeasuredWidth();
            } else {
                bb = bt + getBottomView().getMeasuredHeight();
                br = surfaceArea.right;
            }
        } else if (mode == ShowMode.LayDown) {
            if (this.mDragEdge == DragEdge.Left) {
                br = bl + this.mDragDistance;
            } else if (this.mDragEdge == DragEdge.Right) {
                bl = br - this.mDragDistance;
            } else if (this.mDragEdge == DragEdge.Top) {
                bb = bt + this.mDragDistance;
            } else {
                bt = bb - this.mDragDistance;
            }
        }
        return new Rect(bl, bt, br, bb);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Rect computeBottomLayDown(DragEdge dragEdge) {
        int br;
        int bb;
        int bl = getPaddingLeft();
        int bt = getPaddingTop();
        if (dragEdge == DragEdge.Right) {
            bl = getMeasuredWidth() - this.mDragDistance;
        } else if (dragEdge == DragEdge.Bottom) {
            bt = getMeasuredHeight() - this.mDragDistance;
        }
        if (dragEdge == DragEdge.Left || dragEdge == DragEdge.Right) {
            br = bl + this.mDragDistance;
            bb = bt + getMeasuredHeight();
        } else {
            br = bl + getMeasuredWidth();
            bb = bt + this.mDragDistance;
        }
        return new Rect(bl, bt, br, bb);
    }

    public void addSwipeListener(SwipeListener l) {
        if (this.swipeListeners.size() == 2) {
            this.swipeListeners.remove(1);
        }
        this.swipeListeners.add(l);
    }

    public void removeSwipeListener(SwipeListener l) {
        this.swipeListeners.remove(l);
    }

    public void addOnLayoutListener(OnSwipeLayoutListener l) {
        if (this.mOnLayoutListeners == null) {
            this.mOnLayoutListeners = new ArrayList();
        }
        this.mOnLayoutListeners.add(l);
    }

    public void removeOnLayoutListener(OnSwipeLayoutListener l) {
        if (this.mOnLayoutListeners != null) {
            this.mOnLayoutListeners.remove(l);
        }
    }

    private int dp2px(float dp) {
        return (int) ((getContext().getResources().getDisplayMetrics().density * dp) + 0.5f);
    }
}
