package cn.beekee.zhongtong.view.adapter.util;

import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;
import cn.beekee.zhongtong.view.ZSwipeItem;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

public abstract class BaseSwipeAdapter extends BaseAdapter {
    public static final String TAG = "BaseSwipeAdapter";
    public final int INVALID_POSITION = -1;
    protected Set<ZSwipeItem> mShownLayouts = new HashSet();
    private Mode mode = Mode.Single;
    protected int openPosition = -1;
    protected Set<Integer> openPositions = new HashSet();

    public abstract void fillValues(int i, View view);

    public abstract View generateView(int i, ViewGroup viewGroup);

    public abstract int getSwipeLayoutResourceId(int i);

    public View getView(int position, View convertView, ViewGroup parent) {
        if (convertView == null) {
            convertView = generateView(position, parent);
            initialize(convertView, position);
        } else {
            updateConvertView(convertView, position);
        }
        fillValues(position, convertView);
        return convertView;
    }

    public void initialize(View target, int position) {
        int resId = getSwipeLayoutResourceId(position);
        OnLayoutListener onLayoutListener = new OnLayoutListener(position);
        ZSwipeItem swipeLayout = (ZSwipeItem) target.findViewById(resId);
        if (swipeLayout == null) {
            throw new IllegalStateException("can not find SwipeLayout in target view");
        }
        SwipeMemory swipeMemory = new SwipeMemory(position);
        swipeLayout.addSwipeListener(swipeMemory);
        swipeLayout.addOnLayoutListener(onLayoutListener);
        swipeLayout.setTag(resId, new ValueBox(position, swipeMemory, onLayoutListener));
        this.mShownLayouts.add(swipeLayout);
    }

    public void updateConvertView(View target, int position) {
        int resId = getSwipeLayoutResourceId(position);
        ZSwipeItem swipeLayout = (ZSwipeItem) target.findViewById(resId);
        if (swipeLayout == null) {
            throw new IllegalStateException("can not find SwipeLayout in target view");
        }
        ValueBox valueBox = (ValueBox) swipeLayout.getTag(resId);
        valueBox.swipeMemory.setPosition(position);
        valueBox.onLayoutListener.setPosition(position);
        valueBox.position = position;
        Log.d(TAG, "updateConvertView=" + position);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void closeAllExcept(ZSwipeItem layout) {
        for (ZSwipeItem s : this.mShownLayouts) {
            if (s != layout) {
                s.close();
            }
        }
    }

    public List<Integer> getOpenItems() {
        if (this.mode == Mode.Multiple) {
            return new ArrayList(this.openPositions);
        }
        return Arrays.asList(Integer.valueOf(this.openPosition));
    }

    public boolean isOpen(int position) {
        if (this.mode == Mode.Multiple) {
            return this.openPositions.contains(Integer.valueOf(position));
        }
        return this.openPosition == position;
    }

    public Mode getMode() {
        return this.mode;
    }

    public void setMode(Mode mode2) {
        this.mode = mode2;
        this.openPositions.clear();
        this.mShownLayouts.clear();
        this.openPosition = -1;
    }

    /* access modifiers changed from: package-private */
    public class ValueBox {
        OnLayoutListener onLayoutListener;
        int position;
        SwipeMemory swipeMemory;

        ValueBox(int position2, SwipeMemory swipeMemory2, OnLayoutListener onLayoutListener2) {
            this.swipeMemory = swipeMemory2;
            this.onLayoutListener = onLayoutListener2;
            this.position = position2;
        }
    }

    /* access modifiers changed from: package-private */
    public class OnLayoutListener implements OnSwipeLayoutListener {
        private int position;

        OnLayoutListener(int position2) {
            this.position = position2;
        }

        public void setPosition(int position2) {
            this.position = position2;
        }

        @Override // cn.beekee.zhongtong.view.adapter.util.OnSwipeLayoutListener
        public void onLayout(ZSwipeItem v) {
            if (BaseSwipeAdapter.this.isOpen(this.position)) {
                v.open(false, false);
            } else {
                v.close(false, false);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public class SwipeMemory extends SimpleSwipeListener {
        private int position;

        SwipeMemory(int position2) {
            this.position = position2;
        }

        @Override // cn.beekee.zhongtong.view.adapter.util.SimpleSwipeListener, cn.beekee.zhongtong.view.adapter.util.SwipeListener
        public void onClose(ZSwipeItem layout) {
            if (BaseSwipeAdapter.this.mode == Mode.Multiple) {
                BaseSwipeAdapter.this.openPositions.remove(Integer.valueOf(this.position));
            } else {
                BaseSwipeAdapter.this.openPosition = -1;
            }
        }

        @Override // cn.beekee.zhongtong.view.adapter.util.SimpleSwipeListener, cn.beekee.zhongtong.view.adapter.util.SwipeListener
        public void onStartOpen(ZSwipeItem layout) {
            if (BaseSwipeAdapter.this.mode == Mode.Single) {
                BaseSwipeAdapter.this.closeAllExcept(layout);
            }
        }

        @Override // cn.beekee.zhongtong.view.adapter.util.SimpleSwipeListener, cn.beekee.zhongtong.view.adapter.util.SwipeListener
        public void onOpen(ZSwipeItem layout) {
            if (BaseSwipeAdapter.this.mode == Mode.Multiple) {
                BaseSwipeAdapter.this.openPositions.add(Integer.valueOf(this.position));
                return;
            }
            BaseSwipeAdapter.this.closeAllExcept(layout);
            BaseSwipeAdapter.this.openPosition = this.position;
        }

        public void setPosition(int position2) {
            this.position = position2;
        }
    }
}
