package com.google.zxing.client.result;

public final class CalendarParsedResult extends ParsedResult {
    private final String attendee;
    private final String description;
    private final String end;
    private final double latitude;
    private final String location;
    private final double longitude;
    private final String start;
    private final String summary;

    public CalendarParsedResult(String summary2, String start2, String end2, String location2, String attendee2, String description2) {
        this(summary2, start2, end2, location2, attendee2, description2, Double.NaN, Double.NaN);
    }

    public CalendarParsedResult(String summary2, String start2, String end2, String location2, String attendee2, String description2, double latitude2, double longitude2) {
        super(ParsedResultType.CALENDAR);
        validateDate(start2);
        this.summary = summary2;
        this.start = start2;
        if (end2 != null) {
            validateDate(end2);
            this.end = end2;
        } else {
            this.end = null;
        }
        this.location = location2;
        this.attendee = attendee2;
        this.description = description2;
        this.latitude = latitude2;
        this.longitude = longitude2;
    }

    public String getSummary() {
        return this.summary;
    }

    public String getStart() {
        return this.start;
    }

    public String getEnd() {
        return this.end;
    }

    public String getLocation() {
        return this.location;
    }

    public String getAttendee() {
        return this.attendee;
    }

    public String getDescription() {
        return this.description;
    }

    public double getLatitude() {
        return this.latitude;
    }

    public double getLongitude() {
        return this.longitude;
    }

    @Override // com.google.zxing.client.result.ParsedResult
    public String getDisplayResult() {
        StringBuilder result = new StringBuilder(100);
        maybeAppend(this.summary, result);
        maybeAppend(this.start, result);
        maybeAppend(this.end, result);
        maybeAppend(this.location, result);
        maybeAppend(this.attendee, result);
        maybeAppend(this.description, result);
        return result.toString();
    }

    private static void validateDate(CharSequence date) {
        if (date != null) {
            int length = date.length();
            if (length == 8 || length == 15 || length == 16) {
                for (int i = 0; i < 8; i++) {
                    if (!Character.isDigit(date.charAt(i))) {
                        throw new IllegalArgumentException();
                    }
                }
                if (length <= 8) {
                    return;
                }
                if (date.charAt(8) != 'T') {
                    throw new IllegalArgumentException();
                }
                for (int i2 = 9; i2 < 15; i2++) {
                    if (!Character.isDigit(date.charAt(i2))) {
                        throw new IllegalArgumentException();
                    }
                }
                if (length == 16 && date.charAt(15) != 'Z') {
                    throw new IllegalArgumentException();
                }
                return;
            }
            throw new IllegalArgumentException();
        }
    }
}
