package com.google.zxing.client.result;

import com.google.zxing.Result;
import java.util.regex.Pattern;

public final class EmailDoCoMoResultParser extends AbstractDoCoMoResultParser {
    private static final Pattern ATEXT_ALPHANUMERIC = Pattern.compile("[a-zA-Z0-9@.!#$%&'*+\\-/=?^_`{|}~]+");

    @Override // com.google.zxing.client.result.ResultParser
    public EmailAddressParsedResult parse(Result result) {
        String[] rawTo;
        String rawText = result.getText();
        if (!rawText.startsWith("MATMSG:") || (rawTo = matchDoCoMoPrefixedField("TO:", rawText, true)) == null) {
            return null;
        }
        String to = rawTo[0];
        if (isBasicallyValidEmailAddress(to)) {
            return new EmailAddressParsedResult(to, matchSingleDoCoMoPrefixedField("SUB:", rawText, false), matchSingleDoCoMoPrefixedField("BODY:", rawText, false), "mailto:" + to);
        }
        return null;
    }

    static boolean isBasicallyValidEmailAddress(String email) {
        return email != null && ATEXT_ALPHANUMERIC.matcher(email).matches() && email.indexOf(64) >= 0;
    }
}
