package com.orhanobut.dialogplus;

import android.app.Activity;
import android.content.Context;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.BaseAdapter;
import android.widget.FrameLayout;
import java.util.Arrays;

public class DialogPlusBuilder {
    private static final int INVALID = -1;
    private BaseAdapter adapter;
    private int backgroundColorResourceId;
    private Context context;
    private int defaultContentHeight;
    private boolean expanded;
    private View footerView;
    private int footerViewResourceId;
    private int gravity;
    private View headerView;
    private int headerViewResourceId;
    private Holder holder;
    private int inAnimation;
    private boolean isCancelable;
    private final int[] margin;
    private OnBackPressListener onBackPressListener;
    private OnCancelListener onCancelListener;
    private OnClickListener onClickListener;
    private OnDismissListener onDismissListener;
    private OnItemClickListener onItemClickListener;
    private int outAnimation;
    private final int[] outMostMargin;
    private final int[] padding;
    private final FrameLayout.LayoutParams params;

    private DialogPlusBuilder() {
        this.margin = new int[4];
        this.padding = new int[4];
        this.outMostMargin = new int[4];
        this.params = new FrameLayout.LayoutParams(-1, -2, 80);
        this.gravity = 80;
        this.isCancelable = true;
        this.backgroundColorResourceId = -1;
        this.headerViewResourceId = -1;
        this.footerViewResourceId = -1;
        this.inAnimation = -1;
        this.outAnimation = -1;
    }

    DialogPlusBuilder(Context context2) {
        this.margin = new int[4];
        this.padding = new int[4];
        this.outMostMargin = new int[4];
        this.params = new FrameLayout.LayoutParams(-1, -2, 80);
        this.gravity = 80;
        this.isCancelable = true;
        this.backgroundColorResourceId = -1;
        this.headerViewResourceId = -1;
        this.footerViewResourceId = -1;
        this.inAnimation = -1;
        this.outAnimation = -1;
        if (context2 == null) {
            throw new NullPointerException("Context may not be null");
        }
        this.context = context2;
        Arrays.fill(this.margin, -1);
    }

    public DialogPlusBuilder setAdapter(BaseAdapter adapter2) {
        if (adapter2 == null) {
            throw new NullPointerException("Adapter may not be null");
        }
        this.adapter = adapter2;
        return this;
    }

    public DialogPlusBuilder setFooter(int resourceId) {
        this.footerViewResourceId = resourceId;
        return this;
    }

    public DialogPlusBuilder setFooter(View view) {
        this.footerView = view;
        return this;
    }

    public DialogPlusBuilder setHeader(int resourceId) {
        this.headerViewResourceId = resourceId;
        return this;
    }

    public DialogPlusBuilder setHeader(View view) {
        this.headerView = view;
        return this;
    }

    public DialogPlusBuilder setCancelable(boolean isCancelable2) {
        this.isCancelable = isCancelable2;
        return this;
    }

    public DialogPlusBuilder setContentHolder(Holder holder2) {
        this.holder = holder2;
        return this;
    }

    public DialogPlusBuilder setBackgroundColorResourceId(int resourceId) {
        this.backgroundColorResourceId = resourceId;
        return this;
    }

    public DialogPlusBuilder setGravity(int gravity2) {
        this.gravity = gravity2;
        this.params.gravity = gravity2;
        return this;
    }

    public DialogPlusBuilder setInAnimation(int inAnimResource) {
        this.inAnimation = inAnimResource;
        return this;
    }

    public DialogPlusBuilder setOutAnimation(int outAnimResource) {
        this.outAnimation = outAnimResource;
        return this;
    }

    public DialogPlusBuilder setOutMostMargin(int left, int top, int right, int bottom) {
        this.outMostMargin[0] = left;
        this.outMostMargin[1] = top;
        this.outMostMargin[2] = right;
        this.outMostMargin[3] = bottom;
        return this;
    }

    @Deprecated
    public DialogPlusBuilder setMargins(int left, int top, int right, int bottom) {
        this.margin[0] = left;
        this.margin[1] = top;
        this.margin[2] = right;
        this.margin[3] = bottom;
        return this;
    }

    public DialogPlusBuilder setMargin(int left, int top, int right, int bottom) {
        this.margin[0] = left;
        this.margin[1] = top;
        this.margin[2] = right;
        this.margin[3] = bottom;
        return this;
    }

    public DialogPlusBuilder setPadding(int left, int top, int right, int bottom) {
        this.padding[0] = left;
        this.padding[1] = top;
        this.padding[2] = right;
        this.padding[3] = bottom;
        return this;
    }

    public DialogPlusBuilder setOnItemClickListener(OnItemClickListener listener) {
        this.onItemClickListener = listener;
        return this;
    }

    public DialogPlusBuilder setOnClickListener(OnClickListener listener) {
        this.onClickListener = listener;
        return this;
    }

    public DialogPlusBuilder setOnDismissListener(OnDismissListener listener) {
        this.onDismissListener = listener;
        return this;
    }

    public DialogPlusBuilder setOnCancelListener(OnCancelListener listener) {
        this.onCancelListener = listener;
        return this;
    }

    public DialogPlusBuilder setOnBackPressListener(OnBackPressListener listener) {
        this.onBackPressListener = listener;
        return this;
    }

    public DialogPlusBuilder setExpanded(boolean expanded2) {
        this.expanded = expanded2;
        return this;
    }

    public DialogPlusBuilder setExpanded(boolean expanded2, int defaultContentHeight2) {
        this.expanded = expanded2;
        this.defaultContentHeight = defaultContentHeight2;
        return this;
    }

    public DialogPlusBuilder setContentHeight(int height) {
        this.params.height = height;
        return this;
    }

    public DialogPlusBuilder setContentWidth(int width) {
        this.params.width = width;
        return this;
    }

    public DialogPlus create() {
        init();
        return new DialogPlus(this);
    }

    private void init() {
        if (this.backgroundColorResourceId == -1) {
            this.backgroundColorResourceId = 17170443;
        }
        getHolder().setBackgroundColor(this.backgroundColorResourceId);
    }

    public View getFooterView() {
        return Utils.getView(this.context, this.footerViewResourceId, this.footerView);
    }

    public View getHeaderView() {
        return Utils.getView(this.context, this.headerViewResourceId, this.headerView);
    }

    public Holder getHolder() {
        if (this.holder == null) {
            this.holder = new ListHolder();
        }
        return this.holder;
    }

    public Context getContext() {
        return this.context;
    }

    public BaseAdapter getAdapter() {
        return this.adapter;
    }

    public Animation getInAnimation() {
        return AnimationUtils.loadAnimation(this.context, this.inAnimation == -1 ? Utils.getAnimationResource(this.gravity, true) : this.inAnimation);
    }

    public Animation getOutAnimation() {
        return AnimationUtils.loadAnimation(this.context, this.outAnimation == -1 ? Utils.getAnimationResource(this.gravity, false) : this.outAnimation);
    }

    public FrameLayout.LayoutParams getContentParams() {
        if (this.expanded) {
            this.params.height = getDefaultContentHeight();
        }
        return this.params;
    }

    public boolean isExpanded() {
        return this.expanded;
    }

    public FrameLayout.LayoutParams getOutmostLayoutParams() {
        FrameLayout.LayoutParams params2 = new FrameLayout.LayoutParams(-1, -1);
        params2.setMargins(this.outMostMargin[0], this.outMostMargin[1], this.outMostMargin[2], this.outMostMargin[3]);
        return params2;
    }

    public boolean isCancelable() {
        return this.isCancelable;
    }

    public OnItemClickListener getOnItemClickListener() {
        return this.onItemClickListener;
    }

    public OnClickListener getOnClickListener() {
        return this.onClickListener;
    }

    public OnDismissListener getOnDismissListener() {
        return this.onDismissListener;
    }

    public OnCancelListener getOnCancelListener() {
        return this.onCancelListener;
    }

    public OnBackPressListener getOnBackPressListener() {
        return this.onBackPressListener;
    }

    public int[] getContentMargin() {
        int minimumMargin = this.context.getResources().getDimensionPixelSize(R.dimen.default_center_margin);
        for (int i = 0; i < this.margin.length; i++) {
            this.margin[i] = getMargin(this.gravity, this.margin[i], minimumMargin);
        }
        return this.margin;
    }

    public int[] getContentPadding() {
        return this.padding;
    }

    public int getDefaultContentHeight() {
        Activity activity = (Activity) this.context;
        int displayHeight = activity.getWindowManager().getDefaultDisplay().getHeight() - Utils.getStatusBarHeight(activity);
        if (this.defaultContentHeight == 0) {
            this.defaultContentHeight = (displayHeight * 2) / 5;
        }
        return this.defaultContentHeight;
    }

    private int getMargin(int gravity2, int margin2, int minimumMargin) {
        switch (gravity2) {
            case 17:
                return margin2 != -1 ? margin2 : minimumMargin;
            default:
                if (margin2 == -1) {
                    margin2 = 0;
                }
                return margin2;
        }
    }
}
