package com.orhanobut.dialogplus;

import android.content.Context;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.animation.Animation;
import android.widget.AbsListView;
import android.widget.FrameLayout;

/* access modifiers changed from: package-private */
public class ExpandTouchListener implements View.OnTouchListener {
    private final AbsListView absListView;
    private final View contentContainer;
    private final int defaultContentHeight;
    private final int displayHeight;
    private boolean fullScreen;
    private final GestureDetector gestureDetector;
    private final int gravity;
    private FrameLayout.LayoutParams params;
    private boolean scrollUp;
    private boolean touchUp;
    private float y;

    public static ExpandTouchListener newListener(Context context, AbsListView listView, View container, int gravity2, int displayHeight2, int defaultContentHeight2) {
        return new ExpandTouchListener(context, listView, container, gravity2, displayHeight2, defaultContentHeight2);
    }

    private ExpandTouchListener(Context context, AbsListView absListView2, View container, int gravity2, int displayHeight2, int defaultContentHeight2) {
        this.absListView = absListView2;
        this.contentContainer = container;
        this.gravity = gravity2;
        this.displayHeight = displayHeight2;
        this.defaultContentHeight = defaultContentHeight2;
        this.params = (FrameLayout.LayoutParams) container.getLayoutParams();
        this.gestureDetector = new GestureDetector(context, new GestureDetector.SimpleOnGestureListener() {
            /* class com.orhanobut.dialogplus.ExpandTouchListener.AnonymousClass1 */

            public boolean onSingleTapUp(MotionEvent e) {
                return true;
            }

            public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
                boolean z;
                ExpandTouchListener expandTouchListener = ExpandTouchListener.this;
                if (distanceY > 0.0f) {
                    z = true;
                } else {
                    z = false;
                }
                expandTouchListener.scrollUp = z;
                return false;
            }
        });
    }

    public boolean onTouch(View v, MotionEvent event) {
        if (this.gestureDetector.onTouchEvent(event)) {
            return false;
        }
        if ((this.scrollUp || !Utils.listIsAtTop(this.absListView)) && this.fullScreen) {
            return false;
        }
        switch (event.getAction()) {
            case 0:
                this.y = event.getRawY();
                return true;
            case 1:
                onTouchUp(v, event);
                break;
            case 2:
                if (this.params.height != this.displayHeight) {
                    onTouchMove(v, event);
                    break;
                } else {
                    FrameLayout.LayoutParams layoutParams = this.params;
                    layoutParams.height--;
                    this.contentContainer.setLayoutParams(this.params);
                    return false;
                }
        }
        return true;
    }

    private void onTouchMove(View view, MotionEvent event) {
        boolean z;
        boolean z2 = true;
        if (this.y == -1.0f) {
            this.y = event.getRawY();
        }
        float delta = this.y - event.getRawY();
        if (delta > 0.0f) {
            z = true;
        } else {
            z = false;
        }
        this.touchUp = z;
        if (this.gravity == 48) {
            delta = -delta;
        }
        this.y = event.getRawY();
        int newHeight = this.params.height + ((int) delta);
        if (newHeight > this.displayHeight) {
            newHeight = this.displayHeight;
        }
        if (newHeight < this.defaultContentHeight) {
            newHeight = this.defaultContentHeight;
        }
        this.params.height = newHeight;
        this.contentContainer.setLayoutParams(this.params);
        if (this.params.height != this.displayHeight) {
            z2 = false;
        }
        this.fullScreen = z2;
    }

    private void onTouchUp(View view, MotionEvent event) {
        this.y = -1.0f;
        if (!this.touchUp && this.params.height < this.displayHeight && this.params.height > (this.displayHeight * 4) / 5) {
            Utils.animateContent(this.contentContainer, this.displayHeight, new SimpleAnimationListener() {
                /* class com.orhanobut.dialogplus.ExpandTouchListener.AnonymousClass2 */

                @Override // com.orhanobut.dialogplus.SimpleAnimationListener
                public void onAnimationEnd(Animation animation) {
                    ExpandTouchListener.this.fullScreen = true;
                }
            });
        } else if (this.touchUp && this.params.height > this.defaultContentHeight + 50) {
            Utils.animateContent(this.contentContainer, this.displayHeight, new SimpleAnimationListener() {
                /* class com.orhanobut.dialogplus.ExpandTouchListener.AnonymousClass3 */

                @Override // com.orhanobut.dialogplus.SimpleAnimationListener
                public void onAnimationEnd(Animation animation) {
                    ExpandTouchListener.this.fullScreen = true;
                }
            });
        } else if (this.touchUp && this.params.height <= this.defaultContentHeight + 50) {
            Utils.animateContent(this.contentContainer, this.defaultContentHeight, new SimpleAnimationListener());
        } else if (!this.touchUp && this.params.height > this.defaultContentHeight) {
            Utils.animateContent(this.contentContainer, this.defaultContentHeight, new SimpleAnimationListener());
        }
    }
}
