package com.orhanobut.dialogplus;

import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.GridView;
import android.widget.ListAdapter;

public class GridHolder implements HolderAdapter, AdapterView.OnItemClickListener {
    private int backgroundColor;
    private final int columnNumber;
    private ViewGroup footerContainer;
    private View footerView;
    private GridView gridView;
    private ViewGroup headerContainer;
    private View headerView;
    private View.OnKeyListener keyListener;
    private OnHolderListener listener;

    public GridHolder(int columnNumber2) {
        this.columnNumber = columnNumber2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void addHeader(View view) {
        if (view != null) {
            this.headerContainer.addView(view);
            this.headerView = view;
        }
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void addFooter(View view) {
        if (view != null) {
            this.footerContainer.addView(view);
            this.footerView = view;
        }
    }

    @Override // com.orhanobut.dialogplus.HolderAdapter
    public void setAdapter(BaseAdapter adapter) {
        this.gridView.setAdapter((ListAdapter) adapter);
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void setBackgroundColor(int colorResource) {
        this.backgroundColor = colorResource;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getView(LayoutInflater inflater, ViewGroup parent) {
        View view = inflater.inflate(R.layout.dialog_grid, parent, false);
        this.gridView = (GridView) view.findViewById(R.id.list);
        this.gridView.setBackgroundColor(parent.getResources().getColor(getBackgroundColor()));
        this.gridView.setNumColumns(this.columnNumber);
        this.gridView.setOnItemClickListener(this);
        this.gridView.setOnKeyListener(new View.OnKeyListener() {
            /* class com.orhanobut.dialogplus.GridHolder.AnonymousClass1 */

            public boolean onKey(View v, int keyCode, KeyEvent event) {
                if (GridHolder.this.keyListener != null) {
                    return GridHolder.this.keyListener.onKey(v, keyCode, event);
                }
                throw new NullPointerException("keyListener should not be null");
            }
        });
        this.headerContainer = (ViewGroup) view.findViewById(R.id.header_container);
        this.footerContainer = (ViewGroup) view.findViewById(R.id.footer_container);
        return view;
    }

    @Override // com.orhanobut.dialogplus.HolderAdapter
    public void setOnItemClickListener(OnHolderListener listener2) {
        this.listener = listener2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void setOnKeyListener(View.OnKeyListener keyListener2) {
        this.keyListener = keyListener2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getInflatedView() {
        return this.gridView;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getHeader() {
        return this.headerView;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getFooter() {
        return this.footerView;
    }

    @Override // android.widget.AdapterView.OnItemClickListener
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        if (this.listener != null) {
            this.listener.onItemClick(parent.getItemAtPosition(position), view, position);
        }
    }

    private int getBackgroundColor() {
        if (this.backgroundColor == 0) {
            this.backgroundColor = 17170443;
        }
        return this.backgroundColor;
    }
}
