package com.orhanobut.dialogplus;

import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.ListAdapter;
import android.widget.ListView;

public class ListHolder implements HolderAdapter, AdapterView.OnItemClickListener {
    private int backgroundColor;
    private View footerView;
    private View headerView;
    private View.OnKeyListener keyListener;
    private ListView listView;
    private OnHolderListener listener;

    @Override // com.orhanobut.dialogplus.Holder
    public void addHeader(View view) {
        if (view != null) {
            this.listView.addHeaderView(view);
            this.headerView = view;
        }
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void addFooter(View view) {
        if (view != null) {
            this.listView.addFooterView(view);
            this.footerView = view;
        }
    }

    @Override // com.orhanobut.dialogplus.HolderAdapter
    public void setAdapter(BaseAdapter adapter) {
        this.listView.setAdapter((ListAdapter) adapter);
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void setBackgroundColor(int colorResource) {
        this.backgroundColor = colorResource;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getView(LayoutInflater inflater, ViewGroup parent) {
        View view = inflater.inflate(R.layout.dialog_list, parent, false);
        this.listView = (ListView) view.findViewById(R.id.list);
        if (this.backgroundColor == 0) {
            this.backgroundColor = 17170443;
        }
        this.listView.setBackgroundColor(parent.getResources().getColor(this.backgroundColor));
        this.listView.setOnItemClickListener(this);
        this.listView.setOnKeyListener(new View.OnKeyListener() {
            /* class com.orhanobut.dialogplus.ListHolder.AnonymousClass1 */

            public boolean onKey(View v, int keyCode, KeyEvent event) {
                if (ListHolder.this.keyListener != null) {
                    return ListHolder.this.keyListener.onKey(v, keyCode, event);
                }
                throw new NullPointerException("keyListener should not be null");
            }
        });
        return view;
    }

    @Override // com.orhanobut.dialogplus.HolderAdapter
    public void setOnItemClickListener(OnHolderListener listener2) {
        this.listener = listener2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void setOnKeyListener(View.OnKeyListener keyListener2) {
        this.keyListener = keyListener2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getInflatedView() {
        return this.listView;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getHeader() {
        return this.headerView;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getFooter() {
        return this.footerView;
    }

    @Override // android.widget.AdapterView.OnItemClickListener
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        if (this.listener != null) {
            this.listener.onItemClick(parent.getItemAtPosition(position), view, position);
        }
    }
}
