package com.orhanobut.dialogplus;

import android.view.KeyEvent;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

public class ViewHolder implements Holder {
    private static final int INVALID = -1;
    private int backgroundColor;
    private View contentView;
    private ViewGroup footerContainer;
    private View footerView;
    private ViewGroup headerContainer;
    private View headerView;
    private View.OnKeyListener keyListener;
    private int viewResourceId = -1;

    public ViewHolder(int viewResourceId2) {
        this.viewResourceId = viewResourceId2;
    }

    public ViewHolder(View contentView2) {
        this.contentView = contentView2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void addHeader(View view) {
        if (view != null) {
            this.headerContainer.addView(view);
            this.headerView = view;
        }
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void addFooter(View view) {
        if (view != null) {
            this.footerContainer.addView(view);
            this.footerView = view;
        }
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void setBackgroundColor(int colorResource) {
        this.backgroundColor = colorResource;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getView(LayoutInflater inflater, ViewGroup parent) {
        View view = inflater.inflate(R.layout.dialog_view, parent, false);
        ViewGroup contentContainer = (ViewGroup) view.findViewById(R.id.view_container);
        contentContainer.setBackgroundColor(parent.getResources().getColor(getBackgroundColor()));
        contentContainer.setOnKeyListener(new View.OnKeyListener() {
            /* class com.orhanobut.dialogplus.ViewHolder.AnonymousClass1 */

            public boolean onKey(View v, int keyCode, KeyEvent event) {
                if (ViewHolder.this.keyListener != null) {
                    return ViewHolder.this.keyListener.onKey(v, keyCode, event);
                }
                throw new NullPointerException("keyListener should not be null");
            }
        });
        addContent(inflater, parent, contentContainer);
        this.headerContainer = (ViewGroup) view.findViewById(R.id.header_container);
        this.footerContainer = (ViewGroup) view.findViewById(R.id.footer_container);
        return view;
    }

    private void addContent(LayoutInflater inflater, ViewGroup parent, ViewGroup container) {
        if (this.viewResourceId != -1) {
            this.contentView = inflater.inflate(this.viewResourceId, parent, false);
        } else {
            ViewGroup parentView = (ViewGroup) this.contentView.getParent();
            if (parentView != null) {
                parentView.removeView(this.contentView);
            }
        }
        container.addView(this.contentView);
    }

    @Override // com.orhanobut.dialogplus.Holder
    public void setOnKeyListener(View.OnKeyListener keyListener2) {
        this.keyListener = keyListener2;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getInflatedView() {
        return this.contentView;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getHeader() {
        return this.headerView;
    }

    @Override // com.orhanobut.dialogplus.Holder
    public View getFooter() {
        return this.footerView;
    }

    private int getBackgroundColor() {
        if (this.backgroundColor == 0) {
            this.backgroundColor = 17170443;
        }
        return this.backgroundColor;
    }
}
