package cn.beekee.zhongtong.util.net;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.os.AsyncTask;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;
import cn.beekee.zhongtong.R;
import com.daimajia.numberprogressbar.NumberProgressBar;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URI;
import java.net.URISyntaxException;

public class NetDownAsyncTask extends AsyncTask<Void, Void, Void> {
    private boolean mCancel = false;
    private Context mContext;
    private NumberProgressBar mCustomProgress;
    private AlertDialog mDialog;
    private IDownFileListener mListener;
    private String mMessage = "已下载：";
    private int mProgress = 0;
    private TextView mProgressTip;
    private boolean mShowDialog = true;
    private File mToFile;
    private String mUrl;

    public interface IDownFileListener {
        void downProgress(int i);
    }

    private NetDownAsyncTask(Context context, String url, File toFile, IDownFileListener listener) {
        this.mContext = context;
        this.mUrl = url;
        this.mToFile = toFile;
        this.mListener = listener;
    }

    public static NetDownAsyncTask getDefaultDown(Context context, String url, File toFile, IDownFileListener listener) {
        return new NetDownAsyncTask(context, url, toFile, listener);
    }

    public NetDownAsyncTask setNoDialog() {
        this.mShowDialog = false;
        return this;
    }

    public NetDownAsyncTask setDialogMsg(String msg) {
        if (msg != null) {
            this.mMessage = msg;
        }
        return this;
    }

    /* access modifiers changed from: protected */
    public void onPreExecute() {
        super.onPreExecute();
        if (!NetStatus.isConnect(this.mContext)) {
            this.mProgress = -1;
            Toast.makeText(this.mContext, "请检查网络", 0).show();
        } else if (this.mShowDialog) {
            createDialog();
        }
    }

    private void createDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this.mContext);
        builder.setCancelable(false);
        builder.setNegativeButton("取消", new DialogInterface.OnClickListener() {
            /* class cn.beekee.zhongtong.util.net.NetDownAsyncTask.AnonymousClass1 */

            public void onClick(DialogInterface dialog, int which) {
                NetDownAsyncTask.this.mCancel = true;
                dialog.dismiss();
            }
        });
        View view = LayoutInflater.from(this.mContext).inflate(R.layout.down_file, (ViewGroup) null);
        this.mCustomProgress = (NumberProgressBar) view.findViewById(R.id.progress);
        this.mProgressTip = (TextView) view.findViewById(R.id.text);
        builder.setView(view);
        this.mDialog = builder.show();
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x0096 A[SYNTHETIC, Splitter:B:45:0x0096] */
    /* JADX WARNING: Removed duplicated region for block: B:48:0x009b A[SYNTHETIC, Splitter:B:48:0x009b] */
    public Void doInBackground(Void... params) {
        Exception e;
        if (this.mProgress >= 0) {
            try {
                FileOutputStream outputStream = new FileOutputStream(this.mToFile);
                InputStream inputStream = null;
                try {
                    HttpURLConnection connection = (HttpURLConnection) new URI(this.mUrl).toURL().openConnection();
                    connection.connect();
                    if (connection.getResponseCode() != 200) {
                        this.mProgress = -2;
                        if (0 != 0) {
                            try {
                                inputStream.close();
                            } catch (IOException e2) {
                                e2.printStackTrace();
                            }
                        }
                        if (outputStream != null) {
                            try {
                                outputStream.close();
                            } catch (IOException e3) {
                                e3.printStackTrace();
                            }
                        }
                    } else {
                        InputStream inputStream2 = connection.getInputStream();
                        int length = connection.getContentLength();
                        int count = 0;
                        byte[] bytes = new byte[1024];
                        while (true) {
                            int readLength = inputStream2.read(bytes);
                            if (readLength > 0) {
                                outputStream.write(bytes, 0, readLength);
                                if (this.mCancel) {
                                    this.mProgress = -4;
                                    if (inputStream2 != null) {
                                        try {
                                            inputStream2.close();
                                        } catch (IOException e4) {
                                            e4.printStackTrace();
                                        }
                                    }
                                    if (outputStream != null) {
                                        try {
                                            outputStream.close();
                                        } catch (IOException e5) {
                                            e5.printStackTrace();
                                        }
                                    }
                                } else {
                                    count += readLength;
                                    this.mProgress = (count * 100) / length;
                                    publishProgress(new Void[0]);
                                }
                            } else {
                                if (inputStream2 != null) {
                                    try {
                                        inputStream2.close();
                                    } catch (IOException e6) {
                                        e6.printStackTrace();
                                    }
                                }
                                if (outputStream != null) {
                                    try {
                                        outputStream.close();
                                    } catch (IOException e7) {
                                        e7.printStackTrace();
                                    }
                                }
                            }
                        }
                    }
                } catch (URISyntaxException e8) {
                    e = e8;
                    try {
                        e.printStackTrace();
                        this.mProgress = -2;
                        if (0 != 0) {
                            try {
                                inputStream.close();
                            } catch (IOException e9) {
                                e9.printStackTrace();
                            }
                        }
                        if (outputStream != null) {
                            try {
                                outputStream.close();
                            } catch (IOException e10) {
                                e10.printStackTrace();
                            }
                        }
                        return null;
                    } catch (Throwable th) {
                        if (0 != 0) {
                            try {
                                inputStream.close();
                            } catch (IOException e11) {
                                e11.printStackTrace();
                            }
                        }
                        if (outputStream != null) {
                            try {
                                outputStream.close();
                            } catch (IOException e12) {
                                e12.printStackTrace();
                            }
                        }
                        throw th;
                    }
                } catch (IOException e13) {
                    e = e13;
                    e.printStackTrace();
                    this.mProgress = -2;
                    if (0 != 0) {
                    }
                    if (outputStream != null) {
                    }
                    return null;
                }
            } catch (FileNotFoundException e14) {
                e14.printStackTrace();
                this.mProgress = -3;
            }
        }
        return null;
    }

    /* access modifiers changed from: protected */
    public void onProgressUpdate(Void... values) {
        super.onProgressUpdate((Object[]) values);
        if (this.mShowDialog && this.mDialog != null) {
            this.mCustomProgress.setProgress(this.mProgress);
            this.mProgressTip.setText(this.mMessage + this.mProgress + "%");
        }
    }

    /* access modifiers changed from: protected */
    public void onPostExecute(Void value) {
        if (this.mDialog != null && this.mDialog.isShowing()) {
            this.mDialog.dismiss();
        }
        if (this.mListener != null) {
            this.mListener.downProgress(this.mProgress);
        }
    }
}
